@@ -57,16 +57,18 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         self.resultList.header().resizeSections(QHeaderView.ResizeToContents)
         self.resultList.header().setStretchLastSection(True)
         
-    def __createResultItem(self, parent, strings):
+    def __createResultItem(self, parent, values):
         """
         Private slot to create a new item in the result list.
         
         @param parent parent of the new item (QTreeWidget or QTreeWidgetItem)
-        @param strings strings to be displayed (QStringList)
+        @param values values to be displayed (list)
         @return the generated item
         """
-        itm = QTreeWidgetItem(parent, strings)
-        for col in range(1,7):
+        itm = QTreeWidgetItem(parent)
+        for col in range(len(values)):
+            itm.setData(col, Qt.DisplayRole, values[col])
+        for col in range(1, 7):
             itm.setTextAlignment(col, Qt.Alignment(Qt.AlignRight))
         return itm
         
@@ -128,13 +130,13 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
                 stats = CodeMetrics.analyze(file, total)
                 
                 v = self.__getValues(loc, stats, 'TOTAL ')
-                fitm = self.__createResultItem(self.resultList, QStringList(file) + v)
+                fitm = self.__createResultItem(self.resultList, [file] + v)
                 
                 identifiers = stats.identifiers
                 for identifier in identifiers:
                     v = self.__getValues(loc, stats, identifier)
                     
-                    self.__createResultItem(fitm, QStringList(identifier) + v)
+                    self.__createResultItem(fitm, [identifier] + v)
                 self.resultList.expandItem(fitm)
                 
                 progress += 1
@@ -172,10 +174,10 @@ class CodeMetricsDialog(QDialog, Ui_CodeMetricsDialog):
         @return list of values suitable for display (QStringList)
         """
         counters = stats.counters.get(identifier, {})
-        v = QStringList()
+        v = []
         for key in ('start', 'end', 'lines', 'nloc', 'comments', 'empty'):
             if counters.get(key, 0):
-                v.append(QString("%1").arg(loc.toString(counters[key]), 7, QChar(' ')))
+                v.append(counters[key])
             else:
                 v.append('')
         return v
