@@ -202,7 +202,7 @@ class DebugClientBase(object):
         self.localsFilterObjects = []
 
         self.pendingResponse = ResponseOK
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         self.inRawMode = 0
         self.mainProcStr = None     # used for the passive mode
@@ -463,7 +463,7 @@ class DebugClientBase(object):
                 return
 
             if cmd == RequestLoad:
-                self.fncache = {}
+                self._fncache = {}
                 self.dircache = []
                 sys.argv = []
                 wd, fn, args, tracePython = arg.split('|')
@@ -1122,16 +1122,16 @@ class DebugClientBase(object):
             return fn
 
         # Check the cache.
-        if self.fncache.has_key(fn):
-            return self.fncache[fn]
+        if self._fncache.has_key(fn):
+            return self._fncache[fn]
 
         # Search sys.path.
         for p in sys.path:
             afn = os.path.abspath(os.path.join(p,fn))
-            afn = os.path.normcase(afn)
+            nafn = os.path.normcase(afn)
 
-            if os.path.exists(afn):
-                self.fncache[fn] = afn
+            if os.path.exists(nafn):
+                self._fncache[fn] = afn
                 d = os.path.dirname(afn)
                 if (d not in sys.path) and (d not in self.dircache):
                     self.dircache.append(d)
@@ -1140,10 +1140,10 @@ class DebugClientBase(object):
         # Search the additional directory cache
         for p in self.dircache:
             afn = os.path.abspath(os.path.join(p,fn))
-            afn = os.path.normcase(afn)
+            nafn = os.path.normcase(afn)
             
-            if os.path.exists(afn):
-                self.fncache[fn] = afn
+            if os.path.exists(nafn):
+                self._fncache[fn] = afn
                 return afn
                 
         # Nothing found.
@@ -1341,6 +1341,9 @@ class DebugClientBase(object):
                         try:
                             exec 'mdict = dict%s.__dict__' % access
                             ndict.update(mdict)
+                        except:
+                            pass
+                        try:
                             exec 'mcdict = dict%s.__class__.__dict__' % access
                             ndict.update(mcdict)
                             exec 'obj = dict%s' % access
@@ -1402,7 +1405,7 @@ class DebugClientBase(object):
                     vlist = []
             else:
                 qtVariable = False
-                if len(udict) > 0:
+                if len(dict) == 0 and len(udict) > 0:
                     if access:
                         exec 'qvar = udict%s' % access
                     # this has to be in line with VariablesViewer.indicators
@@ -1755,7 +1758,7 @@ class DebugClientBase(object):
         self.__interact()
         
         # setup the debugger variables
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         self.mainFrame = None
         self.inRawMode = 0
@@ -1794,7 +1797,7 @@ class DebugClientBase(object):
         remoteAddress = self.__resolveHost(host)
         self.connectDebugger(port, remoteAddress, redirect)
         
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         sys.argv = progargs[:]
         sys.argv[0] = os.path.abspath(sys.argv[0])
