@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -548,7 +548,7 @@ class DebugBase(bdb.Bdb):
         self.currentFrame = frame
         self.currentFrameLocals = frame.f_locals
         # remember the locals because it is reinitialized when accessed
-        
+
         fr = frame
         stack = []
         while fr is not None:
@@ -588,6 +588,14 @@ class DebugBase(bdb.Bdb):
         exctype, excval, exctb = excinfo
         if exctype in [SystemExit, bdb.BdbQuit]:
             atexit._run_exitfuncs()
+            if excval is None:
+                excval = 0
+            elif isinstance(excval, str):
+                self._dbgClient.write(excval)
+                excval = 1
+            elif isinstance(excval, bytes):
+                self._dbgClient.write(excval.decode())
+                excval = 1
             if isinstance(excval, int):
                 self._dbgClient.progTerminated(excval)
             else:
