@@ -178,7 +178,7 @@ class DebugClientBase(object):
         self.localsFilterObjects = []
 
         self.pendingResponse = ResponseOK
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         self.inRawMode = False
         self.mainProcStr = None     # used for the passive mode
@@ -450,7 +450,7 @@ class DebugClientBase(object):
                 return
 
             if cmd == RequestLoad:
-                self.fncache = {}
+                self._fncache = {}
                 self.dircache = []
                 sys.argv = []
                 wd, fn, args, tracePython = arg.split('|')
@@ -1120,16 +1120,16 @@ class DebugClientBase(object):
             return fn
 
         # Check the cache.
-        if fn in self.fncache:
-            return self.fncache[fn]
+        if fn in self._fncache:
+            return self._fncache[fn]
 
         # Search sys.path.
         for p in sys.path:
             afn = os.path.abspath(os.path.join(p, fn))
-            afn = os.path.normcase(afn)
+            nafn = os.path.normcase(afn)
 
-            if os.path.exists(afn):
-                self.fncache[fn] = afn
+            if os.path.exists(nafn):
+                self._fncache[fn] = afn
                 d = os.path.dirname(afn)
                 if (d not in sys.path) and (d not in self.dircache):
                     self.dircache.append(d)
@@ -1138,10 +1138,10 @@ class DebugClientBase(object):
         # Search the additional directory cache
         for p in self.dircache:
             afn = os.path.abspath(os.path.join(p, fn))
-            afn = os.path.normcase(afn)
+            nafn = os.path.normcase(afn)
             
-            if os.path.exists(afn):
-                self.fncache[fn] = afn
+            if os.path.exists(nafn):
+                self._fncache[fn] = afn
                 return afn
         
         # Nothing found.
@@ -1344,6 +1344,9 @@ class DebugClientBase(object):
                             mdict = loc["mdict"]
                             obj = loc["obj"]
                             ndict.update(mdict)
+                        except:
+                            pass
+                        try:
                             loc = {"dict": dict}
                             exec('mcdict = dict{0!s}.__class__.__dict__'\
                                  .format(access), globals(), loc)
@@ -1417,7 +1420,7 @@ class DebugClientBase(object):
                     vlist = []
             else:
                 qtVariable = False
-                if len(udict) > 0:
+                if len(dict) == 0 and len(udict) > 0:
                     if access:
                         loc = {"udict" : udict}
                         exec('qvar = udict{0!s}'.format(access), globals(), loc)
@@ -1779,7 +1782,7 @@ class DebugClientBase(object):
         self.__interact()
         
         # setup the debugger variables
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         self.mainFrame = None
         self.inRawMode = False
@@ -1818,7 +1821,7 @@ class DebugClientBase(object):
         remoteAddress = self.__resolveHost(host)
         self.connectDebugger(port, remoteAddress, redirect)
         
-        self.fncache = {}
+        self._fncache = {}
         self.dircache = []
         sys.argv = progargs[:]
         sys.argv[0] = os.path.abspath(sys.argv[0])
