@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,7 @@ import signal
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import QMessageBox
-from PyQt4.QtNetwork import QTcpServer, QHostAddress, QHostInfo
+from PyQt4.QtNetwork import QTcpServer, QHostAddress, QHostInfo, QNetworkInterface
 
 from KdeQt import KQMessageBox
 from KdeQt.KQApplication import e4App
@@ -113,18 +113,24 @@ class DebugServer(QTcpServer):
         elif self.networkInterface == "allv6":
             hostAddress = QHostAddress(QHostAddress.AnyIPv6)
         else:
-            hostAddress = QHostAddress(Preferences.getDebugger("NetworkInterface"))
+            hostAddress = QHostAddress(self.networkInterface)
+        self.networkInterfaceName, self.networkInterfaceIndex = \
+            self.__getNetworkInterfaceAndIndex(self.networkInterface)
+        
         if Preferences.getDebugger("PassiveDbgEnabled"):
-            socket = Preferences.getDebugger("PassiveDbgPort") # default: 42424
-            self.listen(hostAddress, socket)
+            sock = Preferences.getDebugger("PassiveDbgPort") # default: 42424
+            self.listen(hostAddress, sock)
             self.passive = True
             self.passiveClientExited = False
         else:
+            if hostAddress.toString().toLower().startsWith("fe80"):
+                hostAddress.setScopeId(self.networkInterfaceName)
             self.listen(hostAddress)
             self.passive = False
         
         self.debuggerInterface = None
         self.debugging = False
+        self.running = False
         self.clientProcess = None
         self.clientType = Preferences.Prefs.settings.value(\
             'DebugClient/Type', QVariant('Python')).toString()
@@ -181,7 +187,27 @@ class DebugServer(QTcpServer):
             else:
                 return "%s@@v6" % QHostInfo.localHostName()
         else:
-            return self.networkInterface
+            return "{0}@@i{1}".format(self.networkInterface,
+                                      self.networkInterfaceIndex)
+        
+    def __getNetworkInterfaceAndIndex(self, address):
+        """
+        Private method to determine the network interface and the interface index.
+        
+        @param address address to determine the info for (string or QString)
+        @return tuple of network interface name (string) and index (integer)
+        """
+        address = unicode(address)
+        if address not in ["all", "allv6"]:
+            for networkInterface in QNetworkInterface.allInterfaces():
+                addressEntries = networkInterface.addressEntries()
+                if len(addressEntries) > 0:
+                    for addressEntry in addressEntries:
+                        if addressEntry.ip().toString().toLower() == address.lower():
+                            return unicode(networkInterface.name()), \
+                                   networkInterface.index()
+        
+        return "", 0
         
     def preferencesChanged(self):
         """
@@ -294,6 +320,7 @@ class DebugServer(QTcpServer):
         @keyparam runInConsole flag indicating to start the debugger in a 
             console window (boolean)
         """
+        self.running = False
         if not self.passive or not self.passiveClientExited: 
             if self.debuggerInterface and self.debuggerInterface.isConnected():
                 self.shutdownServer()
@@ -650,11 +677,13 @@ class DebugServer(QTcpServer):
         self.debuggerInterface.remoteLoad(fn, argv, wd, tracePython, autoContinue, 
                                           autoFork, forkChild)
         self.debugging = True
+        self.running = True
         self.__restoreBreakpoints()
         self.__restoreWatchpoints()
 
     def remoteRun(self, fn, argv, wd, env, autoClearShell = True,
-                  forProject = False, runInConsole = False):
+                  forProject = False, runInConsole = False, 
+                  autoFork = False, forkChild = False):
         """
         Public method to load a new program to run.
         
@@ -667,6 +696,8 @@ class DebugServer(QTcpServer):
         @keyparam forProject flag indicating a project related action (boolean)
         @keyparam runInConsole flag indicating to start the debugger in a 
             console window (boolean)
+        @keyparam autoFork flag indicating the automatic fork mode (boolean)
+        @keyparam forkChild flag indicating to debug the child after forking (boolean)
         """
         self.__autoClearShell = autoClearShell
         
@@ -679,8 +710,9 @@ class DebugServer(QTcpServer):
         
         self.remoteEnvironment(env)
         
-        self.debuggerInterface.remoteRun(fn, argv, wd)
+        self.debuggerInterface.remoteRun(fn, argv, wd, autoFork, forkChild)
         self.debugging = False
+        self.running = True
 
     def remoteCoverage(self, fn, argv, wd, env, autoClearShell = True,
                        erase = False, forProject = False, runInConsole = False):
@@ -712,6 +744,7 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteCoverage(fn, argv, wd, erase)
         self.debugging = False
+        self.running = True
 
     def remoteProfile(self, fn, argv, wd, env, autoClearShell = True,
                       erase = False, forProject = False, 
@@ -743,6 +776,7 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteProfile(fn, argv, wd, erase)
         self.debugging = False
+        self.running = True
 
     def remoteStatement(self, stmt):
         """
@@ -959,6 +993,7 @@ class DebugServer(QTcpServer):
         
         self.debuggerInterface.remoteUTPrepare(fn, tn, tfn, cov, covname, coverase)
         self.debugging = False
+        self.running = True
         
     def remoteUTRun(self):
         """
@@ -1050,7 +1085,8 @@ class DebugServer(QTcpServer):
         @param stackTrace list of stack entries with the exception position
             first. Each stack entry is a list giving the filename and the linenumber.
         """
-        self.emit(SIGNAL('clientException'), exceptionType, exceptionMessage, stackTrace)
+        if self.running:
+            self.emit(SIGNAL('clientException'), exceptionType, exceptionMessage, stackTrace)
         
     def clientSyntaxError(self, message, filename, lineNo, characterNo):
         """
@@ -1061,7 +1097,8 @@ class DebugServer(QTcpServer):
         @param lineNo line number of the syntax error position (integer)
         @param characterNo character number of the syntax error position (integer)
         """
-        self.emit(SIGNAL('clientSyntaxError'), message, filename, lineNo, characterNo)
+        if self.running:
+            self.emit(SIGNAL('clientSyntaxError'), message, filename, lineNo, characterNo)
         
     def clientExit(self, status):
         """
@@ -1078,6 +1115,7 @@ class DebugServer(QTcpServer):
             self.__createDebuggerInterface("None")
             self.clientOutput(self.trUtf8('\nNot connected\n'))
             self.clientStatement(False)
+        self.running = False
         
     def clientClearBreak(self, filename, lineno):
         """
@@ -1210,6 +1248,7 @@ class DebugServer(QTcpServer):
         print unicode(self.trUtf8("Passive debug connection received"))
         self.passiveClientExited = False
         self.debugging = True
+        self.running = True
         self.__restoreBreakpoints()
         self.__restoreWatchpoints()
         self.emit(SIGNAL('passiveDebugStarted'), fn, exc)
