@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,6 +41,8 @@ class DebugUI(QObject):
     @signal resetUI() emitted to reset the UI
     @signal exceptionInterrupt() emitted after the execution was interrupted by an
         exception and acknowledged by the user
+    @signal appendStdout(msg) emitted when the client program has terminated and the
+        display of the termination dialog is suppressed
     """
     def __init__(self, ui, vm, debugServer, debugViewer, project):
         """
@@ -966,6 +968,17 @@ class DebugUI(QObject):
                                 ' status of %2.</p>')
                         .arg(Utilities.normabspath(self.ui.currentProg))
                         .arg(status))
+        else:
+            if self.ui.currentProg is None:
+                self.emit(SIGNAL("appendStdout"), 
+                    self.trUtf8('The program has terminated with an exit'
+                                ' status of %1.\n').arg(status))
+            else:
+                self.emit(SIGNAL("appendStdout"), 
+                    self.trUtf8('"%1" has terminated with an exit'
+                                ' status of %2.\n')
+                        .arg(Utilities.normabspath(self.ui.currentProg))
+                        .arg(status))
 
     def __clientSyntaxError(self, message, filename, lineNo, characterNo):
         """
@@ -1574,9 +1587,12 @@ class DebugUI(QObject):
             cap = self.trUtf8("Run Script")
         dlg = StartDialog(cap, self.argvHistory, self.wdHistory, self.envHistory, 
             self.exceptions, self.ui, 1,
-            autoClearShell = self.autoClearShell)
+            autoClearShell = self.autoClearShell, 
+            autoFork = self.forkAutomatically, 
+            forkChild = self.forkIntoChild)
         if dlg.exec_() == QDialog.Accepted:
             argv, wd, env, exceptions, clearShell, clearHistories, console = dlg.getData()
+            forkAutomatically, forkIntoChild = dlg.getRunData()
             
             if runProject:
                 fn = self.project.getMainScript(1)
@@ -1628,6 +1644,10 @@ class DebugUI(QObject):
             # Save the run in console flag
             self.runInConsole = console
             
+            # Save the forking flags
+            self.forkAutomatically = forkAutomatically
+            self.forkIntoChild = forkIntoChild
+            
             # Hide all error highlights
             self.viewmanager.unhighlight()
             
@@ -1639,7 +1659,8 @@ class DebugUI(QObject):
                 # Ask the client to open the new program.
                 self.debugServer.remoteRun(fn, argv, wd, env,
                     autoClearShell = self.autoClearShell, forProject = runProject, 
-                    runInConsole = console)
+                    runInConsole = console, autoFork = forkAutomatically, 
+                    forkChild = forkIntoChild)
                 
                 self.stopAct.setEnabled(True)
         
@@ -1811,16 +1832,20 @@ class DebugUI(QObject):
                 
                 # Signal that we have started a debugging session
                 self.emit(SIGNAL('debuggingStarted'), fn)
+            
             elif self.lastStartAction in [3, 4]:
                 # Ask the client to run the new program.
                 self.debugServer.remoteRun(fn, argv, wd, env, 
                     autoClearShell = self.autoClearShell, forProject = forProject, 
-                    runInConsole = self.runInConsole)
+                    runInConsole = self.runInConsole, autoFork = self.forkAutomatically, 
+                    forkChild = self.forkIntoChild)
+            
             elif self.lastStartAction in [5, 6]:
                 # Ask the client to coverage run the new program.
                 self.debugServer.remoteCoverage(fn, argv, wd, env, 
                     autoClearShell = self.autoClearShell, erase = self.eraseCoverage,
                     forProject = forProject, runInConsole = self.runInConsole)
+            
             elif self.lastStartAction in [7, 8]:
                 # Ask the client to profile run the new program.
                 self.debugServer.remoteProfile(fn, argv, wd, env, 
