@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -80,7 +80,7 @@ class DebuggerInterfaceNone(QObject):
         """
         Public slot to handle a new connection.
         
-        @param sockreference to the socket object (QTcpSocket)
+        @param sock reference to the socket object (QTcpSocket)
         @return flag indicating success (boolean)
         """
         return False
@@ -134,13 +134,15 @@ class DebuggerInterfaceNone(QObject):
         """
         return
         
-    def remoteRun(self, fn, argv, wd):
+    def remoteRun(self, fn, argv, wd, autoFork = False, forkChild = False):
         """
         Public method to load a new program to run.
         
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string or QString)
         @param wd the working directory for the program (string)
+        @keyparam autoFork flag indicating the automatic fork mode (boolean)
+        @keyparam forkChild flag indicating to debug the child after forking (boolean)
         """
         return
         
