@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -113,9 +113,10 @@ class DebuggerInterfaceRuby(QObject):
         @param program name of the executable to start (string)
         @param arguments arguments to be passed to the program (list of string)
         @param environment dictionary of environment settings to pass (dict of string)
-        @return the process object (QProcess) or None
+        @return the process object (QProcess) or None and an error string (QString)
         """
         proc = QProcess()
+        errorStr = QString()
         if environment is not None:
             env = QStringList()
             for key, value in environment.items():
@@ -126,9 +127,10 @@ class DebuggerInterfaceRuby(QObject):
             args.append(arg)
         proc.start(program, args)
         if not proc.waitForStarted(10000):
+            errorStr = proc.errorString()
             proc = None
         
-        return proc
+        return proc, errorStr
         
     def startRemote(self, port, runInConsole):
         """
@@ -159,12 +161,13 @@ class DebuggerInterfaceRuby(QObject):
                        [rhost, interpreter, os.path.abspath(debugClient),
                         str(port), redirect, ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process = self.__startProcess(args[0], args[1:])
+                process, error = self.__startProcess(args[0], args[1:])
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""))
+                            """<p>The debugger backend could not be started.</p>"""
+                            """<p>Reason: %1</p>""").arg(error))
                 
                 # set translation function
                 if Preferences.getDebugger("PathTranslation"):
@@ -204,21 +207,24 @@ class DebuggerInterfaceRuby(QObject):
                        [interpreter, os.path.abspath(debugClient),
                         str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process = self.__startProcess(args[0], args[1:], clientEnv)
+                process, error = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""))
+                            """<p>The debugger backend could not be started.</p>"""
+                            """<p>Reason: %1</p>""").arg(error))
                 return process, self.__isNetworked
         
-        process = self.__startProcess(interpreter, 
+        process, error = self.__startProcess(interpreter, 
             [debugClient, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
                 self.trUtf8("Start Debugger"),
-                self.trUtf8("""<p>The debugger backend could not be started.</p>"""))
+                self.trUtf8(
+                    """<p>The debugger backend could not be started.</p>"""
+                    """<p>Reason: %1</p>""").arg(error))
         return process, self.__isNetworked
 
     def startRemoteForProject(self, port, runInConsole):
@@ -252,12 +258,13 @@ class DebuggerInterfaceRuby(QObject):
                        [rhost, interpreter, os.path.abspath(debugClient),
                         str(port), redirect, ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process = self.__startProcess(args[0], args[1:])
+                process, error = self.__startProcess(args[0], args[1:])
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""))
+                            """<p>The debugger backend could not be started.</p>"""
+                            """<p>Reason: %1</p>""").arg(error))
                 # set translation function
                 if project.getDebugProperty("PATHTRANSLATION"):
                     self.translateRemote = project.getDebugProperty("REMOTEPATH")
@@ -295,21 +302,24 @@ class DebuggerInterfaceRuby(QObject):
                        [interpreter, os.path.abspath(debugClient),
                         str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
-                process = self.__startProcess(args[0], args[1:], clientEnv)
+                process, error = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
                     KQMessageBox.critical(None,
                         self.trUtf8("Start Debugger"),
                         self.trUtf8(\
-                            """<p>The debugger backend could not be started.</p>"""))
+                            """<p>The debugger backend could not be started.</p>"""
+                            """<p>Reason: %1</p>""").arg(error))
                 return process, self.__isNetworked
         
-        process = self.__startProcess(interpreter, 
+        process, error = self.__startProcess(interpreter, 
             [debugClient, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
                 self.trUtf8("Start Debugger"),
-                self.trUtf8("""<p>The debugger backend could not be started.</p>"""))
+                self.trUtf8(
+                    """<p>The debugger backend could not be started.</p>"""
+                    """<p>Reason: %1</p>""").arg(error))
         return process, self.__isNetworked
 
     def getClientCapabilities(self):
@@ -324,7 +334,7 @@ class DebuggerInterfaceRuby(QObject):
         """
         Public slot to handle a new connection.
         
-        @param sockreference to the socket object (QTcpSocket)
+        @param sock reference to the socket object (QTcpSocket)
         @return flag indicating success (boolean)
         """
         # If we already have a connection, refuse this one.  It will be closed
@@ -416,13 +426,15 @@ class DebuggerInterfaceRuby(QObject):
             (RequestLoad, unicode(wd),
              unicode(fn), unicode(Utilities.parseOptionString(argv)), traceInterpreter))
         
-    def remoteRun(self, fn, argv, wd):
+    def remoteRun(self, fn, argv, wd, autoFork = False, forkChild = False):
         """
         Public method to load a new program to run.
         
         @param fn the filename to run (string)
         @param argv the commandline arguments to pass to the program (string or QString)
         @param wd the working directory for the program (string)
+        @keyparam autoFork flag indicating the automatic fork mode (boolean)
+        @keyparam forkChild flag indicating to debug the child after forking (boolean)
         """
         wd = self.translate(wd, False)
         fn = self.translate(os.path.abspath(unicode(fn)), False)
