@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -104,7 +104,11 @@ class StartDialog(QDialog):
             self.ui.forkModeCheckBox.setChecked(autoFork)
             self.ui.forkChildCheckBox.setChecked(forkChild)
         
-        if type == 3:   # start coverage or profile dialog
+        if type == 1:       # start run dialog
+            self.ui.forkModeCheckBox.setChecked(autoFork)
+            self.ui.forkChildCheckBox.setChecked(forkChild)
+        
+        if type == 3:       # start coverage or profile dialog
             self.ui.eraseCheckBox.setChecked(True)
         
         self.__clearHistoryLists = False
@@ -167,6 +171,18 @@ class StartDialog(QDialog):
                     self.ui.forkModeCheckBox.isChecked(), 
                     self.ui.forkChildCheckBox.isChecked())
         
+    def getRunData(self):
+        """
+        Public method to retrieve the debug related data entered into this dialog.
+        
+        @return a tuple of a flag indicating, that the debugger should fork automatically
+            (boolean) and a flag indicating, that the debugger should debug the child 
+            process after forking automatically (boolean)
+        """
+        if self.type == 1:
+            return (self.ui.forkModeCheckBox.isChecked(), 
+                    self.ui.forkChildCheckBox.isChecked())
+        
     def getCoverageData(self):
         """
         Public method to retrieve the coverage related data entered into this dialog.
