@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -18,7 +18,7 @@ import TemplatesListsStyle
 import TemplatesListsStyleCSS
 
 from Utilities import html_uencode
-from Utilities.ModuleParser import RB_SOURCE
+from Utilities.ModuleParser import RB_SOURCE, Function
 
 _signal = re.compile(r"""
     ^@signal [ \t]+ 
@@ -364,7 +364,12 @@ class ModuleDocument(object):
                 supers = 'None'
             
             globalsList = self.__genGlobalsListSection(_class)
-            methList, methBodies = self.__genMethodSection(_class, className)
+            classMethList, classMethBodies = \
+                self.__genMethodSection(_class, className, Function.Class)
+            methList, methBodies = \
+                self.__genMethodSection(_class, className, Function.General)
+            staticMethList, staticMethBodies = \
+                self.__genMethodSection(_class, className, Function.Static)
             
             try:
                 clsBody = self.classTemplate % { \
@@ -373,8 +378,10 @@ class ModuleDocument(object):
                     'ClassSuper' : supers,
                     'ClassDescription' : self.__formatDescription(_class.description),
                     'GlobalsList' : globalsList, 
+                    'ClassMethodList': classMethList,
                     'MethodList' : methList,
-                    'MethodDetails' : methBodies,
+                    'StaticMethodList': staticMethList,
+                    'MethodDetails': classMethBodies + methBodies + staticMethBodies,
                 }
             except TagError, e:
                 sys.stderr.write("Error in tags of description of class %s.\n" % \
@@ -386,30 +393,35 @@ class ModuleDocument(object):
             
         return ''.join(classes)
         
-    def __genMethodsListSection(self, names, dict, className, clsName):
+    def __genMethodsListSection(self, names, dict, className, clsName,
+                                includeInit=True):
         """
         Private method to generate the methods list section of a class.
         
-        @param names The names to appear in the list. (list of strings)
-        @param dict A dictionary containing all relevant information.
-        @param className The class name containing the names.
-        @param clsName The visible class name containing the names.
-        @return The list section. (string)
+        @param names names to appear in the list (list of strings)
+        @param dict dictionary containing all relevant information
+        @param className class name containing the names
+        @param clsName visible class name containing the names
+        @param includeInit flag indicating to include the __init__ method (boolean)
+        @return methods list section (string)
         """
         lst = []
-        try:
-            lst.append(self.listEntryTemplate % { \
-                'Link' : "%s.%s" % (className, '__init__'),
-                'Name' : clsName,
-                'Description' : self.__getShortDescription(dict['__init__'].description),
-                'Deprecated' : self.__checkDeprecated(dict['__init__'].description) and \
-                               self.listEntryDeprecatedTemplate or "",
-            })
-            self.keywords.append(("%s (Constructor)" % className, 
-                                  "#%s.%s" % (className, '__init__')))
-        except KeyError:
-            pass
-            
+        if includeInit:
+            try:
+                lst.append(self.listEntryTemplate % { \
+                    'Link' : "%s.%s" % (className, '__init__'),
+                    'Name' : clsName,
+                    'Description' : self.__getShortDescription(
+                                        dict['__init__'].description),
+                    'Deprecated' : self.__checkDeprecated(
+                                        dict['__init__'].description) and \
+                                   self.listEntryDeprecatedTemplate or "",
+                })
+                self.keywords.append(("%s (Constructor)" % className, 
+                                      "#%s.%s" % (className, '__init__')))
+            except KeyError:
+                pass
+        
         for name in names:
             lst.append(self.listEntryTemplate % { \
                 'Link' : "%s.%s" % (className, name),
@@ -422,17 +434,18 @@ class ModuleDocument(object):
                                   "#%s.%s" % (className, name)))
         return ''.join(lst)
         
-    def __genMethodSection(self, obj, className):
+    def __genMethodSection(self, obj, className, filter):
         """
         Private method to generate the method details section.
         
-        @param obj Reference to the object being formatted.
-        @param className Name of the class containing the method. (string)
-        @return The method list and method details section. (tuple of two string)
+        @param obj reference to the object being formatted
+        @param className name of the class containing the method (string)
+        @param filter filter value designating the method types
+        @return method list and method details section (tuple of two string)
         """
         methList = []
         methBodies = []
-        methods = obj.methods.keys()
+        methods = [k for k in obj.methods.keys() if obj.methods[k].modifier == filter]
         methods.sort()
         
         # first do the constructor
@@ -453,13 +466,20 @@ class ModuleDocument(object):
                 sys.stderr.write("%s\n" % e)
                 methBody = ""
             methBodies.append(methBody)
-            
+        
+        if filter == Function.Class:
+            methodClassifier = " (class method)"
+        elif filter == Function.Static:
+            methodClassifier = " (static)"
+        else:
+            methodClassifier = ""
         for method in methods:
             try:
                 methBody = self.methodTemplate % { \
                     'Anchor' : className,
                     'Class' : obj.name,
                     'Method' : obj.methods[method].name,
+                    'MethodClassifier': methodClassifier,
                     'MethodDescription' : \
                         self.__formatDescription(obj.methods[method].description),
                     'Params' : ', '.join(obj.methods[method].parameters[1:]),
@@ -471,7 +491,8 @@ class ModuleDocument(object):
                 methBody = ""
             methBodies.append(methBody)
             
-        methList = self.__genMethodsListSection(methods, obj.methods, className, obj.name)
+        methList = self.__genMethodsListSection(methods, obj.methods, className,
+            obj.name, includeInit=filter == Function.General)
         
         if not methList:
             methList = self.listEntryNoneTemplate
@@ -491,7 +512,8 @@ class ModuleDocument(object):
         for rbModuleName in rbModulesNames:
             rbModule = self.module.modules[rbModuleName]
             globalsList = self.__genGlobalsListSection(rbModule)
-            methList, methBodies = self.__genMethodSection(rbModule, rbModuleName)
+            methList, methBodies = \
+                self.__genMethodSection(rbModule, rbModuleName, Function.General)
             classList, classBodies = \
                 self.__genRbModulesClassesSection(rbModule, rbModuleName)
             
@@ -536,7 +558,8 @@ class ModuleDocument(object):
                 supers = 'None'
             
             classname = "%s.%s" % (modName, className)
-            methList, methBodies = self.__genMethodSection(_class, className)
+            methList, methBodies = \
+                self.__genMethodSection(_class, className, Function.General)
             
             try:
                 clsBody = self.rbModulesClassTemplate % { \
