@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -62,15 +62,19 @@ classTemplate = \
 %%(ClassSuper)s
 <h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">Class Attributes</h3>
 %%(GlobalsList)s
+<h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">Class Methods</h3>
+%%(ClassMethodList)s
 <h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">Methods</h3>
 %%(MethodList)s
+<h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">Static Methods</h3>
+%%(StaticMethodList)s
 %%(MethodDetails)s
 <div align="right"><a style="color:%(LinkColor)s" href="#top">Up</a></div>
 <hr />'''
 
 methodTemplate = \
 '''<a NAME="%%(Anchor)s.%%(Method)s" ID="%%(Anchor)s.%%(Method)s"></a>
-<h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">%%(Class)s.%%(Method)s</h3>
+<h3 style="background-color:%(Level2HeaderBgColor)s;color:%(Level2HeaderColor)s">%%(Class)s.%%(Method)s%%(MethodClassifier)s</h3>
 <b>%%(Method)s</b>(<i>%%(Params)s</i>)
 %%(MethodDescription)s'''
 
