@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -65,15 +65,19 @@ classTemplate = \
 %(ClassSuper)s
 <h3>Class Attributes</h3>
 %(GlobalsList)s
+<h3>Class Methods</h3>
+%(ClassMethodList)s
 <h3>Methods</h3>
 %(MethodList)s
+<h3>Static Methods</h3>
+%(StaticMethodList)s
 %(MethodDetails)s
 <div align="right"><a href="#top">Up</a></div>
 <hr />'''
 
 methodTemplate = \
 '''<a NAME="%(Anchor)s.%(Method)s" ID="%(Anchor)s.%(Method)s"></a>
-<h4>%(Class)s.%(Method)s</h4>
+<h4>%(Class)s.%(Method)s%(MethodClassifier)s</h4>
 <b>%(Method)s</b>(<i>%(Params)s</i>)
 %(MethodDescription)s'''
 
@@ -177,7 +181,7 @@ exceptionsListEntryTemplate = \
 </dd>'''
 
 signalsListTemplate = \
-'''<h4>Signals</h4>
+'''<h3>Signals</h3>
 <dl>
 %(Signals)s
 </dl>'''
@@ -189,7 +193,7 @@ signalsListEntryTemplate = \
 </dd>'''
 
 eventsListTemplate = \
-'''<h4>Events</h4>
+'''<h3>Events</h3>
 <dl>
 %(Events)s
 </dl>'''
