@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,8 +8,9 @@ Module implementing a sidebar class.
 """
 
 from PyQt4.QtCore import SIGNAL,  SLOT, QEvent, QSize, Qt, QByteArray, \
-                         QDataStream, QIODevice
-from PyQt4.QtGui import QTabBar, QWidget, QStackedWidget, QBoxLayout, QToolButton
+    QDataStream, QIODevice
+from PyQt4.QtGui import QTabBar, QWidget, QStackedWidget, QBoxLayout, QToolButton, \
+    QSizePolicy
 
 from KdeQt.KQApplication import e4App
 
@@ -39,6 +40,8 @@ class E4SideBar(QWidget):
         self.__tabBar = QTabBar()
         self.__tabBar.setDrawBase(True)
         self.__tabBar.setShape(QTabBar.RoundedNorth)
+        self.__tabBar.setUsesScrollButtons(True)
+        self.__tabBar.setDrawBase(False)
         self.__stackedWidget = QStackedWidget(self)
         self.__stackedWidget.setContentsMargins(0, 0, 0, 0)
         self.__autoHideButton = QToolButton()
@@ -92,6 +95,9 @@ class E4SideBar(QWidget):
         self.splitter = splitter
         self.connect(self.splitter, SIGNAL("splitterMoved(int, int)"), 
                      self.__splitterMoved)
+        self.splitter.setChildrenCollapsible(False)
+        index = self.splitter.indexOf(self)
+        self.splitter.setCollapsible(index, False)
     
     def __splitterMoved(self, pos, index):
         """
@@ -110,12 +116,13 @@ class E4SideBar(QWidget):
         self.__minimized = True
         self.__bigSize = self.size()
         if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.__minSize = self.minimumHeight()
+            self.__minSize = self.minimumSizeHint().height()
             self.__maxSize = self.maximumHeight()
         else:
-            self.__minSize = self.minimumWidth()
+            self.__minSize = self.minimumSizeHint().width()
             self.__maxSize = self.maximumWidth()
-        self.splitterSizes = self.splitter.sizes()
+        if self.splitter:
+            self.splitterSizes = self.splitter.sizes()
         
         self.__stackedWidget.hide()
         
@@ -132,12 +139,15 @@ class E4SideBar(QWidget):
         self.__stackedWidget.show()
         self.resize(self.__bigSize)
         if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-            self.setMinimumHeight(self.__minSize)
+            minSize = max(self.__minSize, self.minimumSizeHint().height())
+            self.setMinimumHeight(minSize)
             self.setMaximumHeight(self.__maxSize)
         else:
-            self.setMinimumWidth(self.__minSize)
+            minSize = max(self.__minSize, self.minimumSizeHint().width())
+            self.setMinimumWidth(minSize)
             self.setMaximumWidth(self.__maxSize)
-        self.splitter.setSizes(self.splitterSizes)
+        if self.splitter:
+            self.splitter.setSizes(self.splitterSizes)
     
     def isMinimized(self):
         """
@@ -198,10 +208,16 @@ class E4SideBar(QWidget):
             used, if the second parameter is a QIcon)
         """
         if label:
-            self.__tabBar.addTab(iconOrLabel, label)
+            index = self.__tabBar.addTab(iconOrLabel, label)
+            self.__tabBar.setTabToolTip(index, label)
         else:
-            self.__tabBar.addTab(iconOrLabel)
+            index = self.__tabBar.addTab(iconOrLabel)
+            self.__tabBar.setTabToolTip(index, iconOrLabel)
         self.__stackedWidget.addWidget(widget)
+        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
+            self.__minSize = self.minimumSizeHint().height()
+        else:
+            self.__minSize = self.minimumSizeHint().width()
     
     def insertTab(self, index, widget, iconOrLabel, label = None):
         """
@@ -215,10 +231,16 @@ class E4SideBar(QWidget):
             used, if the second parameter is a QIcon)
         """
         if label:
-            self.__tabBar.insertTab(index, iconOrLabel, label)
+            index = self.__tabBar.insertTab(index, iconOrLabel, label)
+            self.__tabBar.setTabToolTip(index, label)
         else:
-            self.__tabBar.insertTab(index, iconOrLabel)
+            index = self.__tabBar.insertTab(index, iconOrLabel)
+            self.__tabBar.setTabToolTip(index, iconOrLabel)
         self.__stackedWidget.insertWidget(index, widget)
+        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
+            self.__minSize = self.minimumSizeHint().height()
+        else:
+            self.__minSize = self.minimumSizeHint().width()
     
     def removeTab(self, index):
         """
@@ -228,6 +250,10 @@ class E4SideBar(QWidget):
         """
         self.__stackedWidget.removeWidget(self.__stackedWidget.widget(index))
         self.__tabBar.removeTab(index)
+        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
+            self.__minSize = self.minimumSizeHint().height()
+        else:
+            self.__minSize = self.minimumSizeHint().width()
     
     def clear(self):
         """
@@ -346,21 +372,25 @@ class E4SideBar(QWidget):
         """
         if orient == E4SideBar.North:
             self.__tabBar.setShape(QTabBar.RoundedNorth)
+            self.__tabBar.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
             self.barLayout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setAlignment(self.barLayout, Qt.AlignLeft)
         elif orient == E4SideBar.East:
             self.__tabBar.setShape(QTabBar.RoundedEast)
+            self.__tabBar.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
             self.barLayout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setDirection(QBoxLayout.RightToLeft)
             self.layout.setAlignment(self.barLayout, Qt.AlignTop)
         elif orient == E4SideBar.South:
             self.__tabBar.setShape(QTabBar.RoundedSouth)
+            self.__tabBar.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
             self.barLayout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setDirection(QBoxLayout.BottomToTop)
             self.layout.setAlignment(self.barLayout, Qt.AlignLeft)
         elif orient == E4SideBar.West:
             self.__tabBar.setShape(QTabBar.RoundedWest)
+            self.__tabBar.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
             self.barLayout.setDirection(QBoxLayout.TopToBottom)
             self.layout.setDirection(QBoxLayout.LeftToRight)
             self.layout.setAlignment(self.barLayout, Qt.AlignTop)
@@ -454,13 +484,14 @@ class E4SideBar(QWidget):
         @return saved state as a byte array (QByteArray)
         """
         if len(self.splitterSizes) == 0:
-            self.splitterSizes = self.splitter.sizes()
+            if self.splitter:
+                self.splitterSizes = self.splitter.sizes()
             self.__bigSize = self.size()
             if self.__orientation in [E4SideBar.North, E4SideBar.South]:
-                self.__minSize = self.minimumHeight()
+                self.__minSize = self.minimumSizeHint().height()
                 self.__maxSize = self.maximumHeight()
             else:
-                self.__minSize = self.minimumWidth()
+                self.__minSize = self.minimumSizeHint().width()
                 self.__maxSize = self.maximumWidth()
         
         data = QByteArray()
@@ -488,17 +519,24 @@ class E4SideBar(QWidget):
         if state.isEmpty():
             return False
         
+        if self.__orientation in [E4SideBar.North, E4SideBar.South]:
+            minSize = self.layout.minimumSize().height()
+            maxSize = self.maximumHeight()
+        else:
+            minSize = self.layout.minimumSize().width()
+            maxSize = self.maximumWidth()
+        
         data = QByteArray(state)
         stream = QDataStream(data, QIODevice.ReadOnly)
-        stream.readUInt16()   # version
+        stream.readUInt16()  # version
         minimized = stream.readBool()
         
         if minimized:
             self.shrink()
         
         stream >> self.__bigSize
-        self.__minSize = stream.readUInt16()
-        self.__maxSize = stream.readUInt16()
+        self.__minSize = max(stream.readUInt16(), minSize)
+        self.__maxSize = max(stream.readUInt16(), maxSize)
         count = stream.readUInt16()
         self.splitterSizes = []
         for i in range(count):
