@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -81,7 +81,7 @@ class E4DnDTabBar(E4WheelTabBar):
             index = self.tabAt(event.pos())
             mimeData.setText(self.tabText(index))
             mimeData.setData("action", "tab-reordering")
-            mimeData.setData("tabbar-id", QByteArray.number(id(self)))
+            mimeData.setData("tabbar-id", str(id(self)))
             drag.setMimeData(mimeData)
             drag.exec_()
         E4WheelTabBar.mouseMoveEvent(self, event)
@@ -97,7 +97,7 @@ class E4DnDTabBar(E4WheelTabBar):
         if formats.contains("action") and \
            mimeData.data("action") == "tab-reordering" and \
            formats.contains("tabbar-id") and \
-           mimeData.data("tabbar-id").toLong()[0] == id(self):
+           long(mimeData.data("tabbar-id")) == id(self):
             event.acceptProposedAction()
         E4WheelTabBar.dragEnterEvent(self, event)
     
