@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,26 +23,6 @@ class E4VerticalToolBox(QToolBox):
         @param parent reference to the parent widget (QWidget)
         """
         QToolBox.__init__(self, parent)
-    
-    def wheelEvent(self, event):
-        """
-        Protected slot to support wheel events.
-        
-        @param reference to the wheel event (QWheelEvent)
-        """
-        index = self.currentIndex()
-        if event.delta() > 0:
-            index -= 1
-        else:
-            index += 1
-        if index < 0:
-            index = self.count() - 1
-        elif index == self.count():
-            index = 0
-        
-        self.setCurrentIndex(index)
-        
-        event.accept()
 
 class E4HorizontalToolBox(E4TabWidget):
     """
@@ -56,6 +36,7 @@ class E4HorizontalToolBox(E4TabWidget):
         """
         E4TabWidget.__init__(self, parent)
         self.setTabPosition(QTabWidget.West)
+        self.setUsesScrollButtons(True)
     
     def addItem(self, widget, icon, text):
         """
