@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -88,7 +88,8 @@ class ApplicationDiagram(UMLDialog):
         """
         Private method to build the packages shapes of the diagram.
         """
-        project = os.path.splitdrive(self.project.ppath)[1].replace(os.sep, '.')[1:]
+        project = os.path.splitdrive(self.project.getProjectPath())[1]\
+            .replace(os.sep, '.')[1:]
         packages = {}
         shapes = {}
         p = 10
