@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,6 +9,7 @@ Module implementing a tool bar showing bookmarks.
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
+from PyQt4.QtWebKit import QWebPage
 
 from E4Gui.E4ModelToolBar import E4ModelToolBar
 
@@ -29,16 +30,18 @@ class BookmarksToolBar(E4ModelToolBar):
             tab
     @signal newUrl(const QUrl&, const QString&) emitted to open a URL in a new tab
     """
-    def __init__(self, model, parent = None):
+    def __init__(self, mainWindow, model, parent = None):
         """
         Constructor
         
+        @param mainWindow reference to the main window (HelpWindow)
         @param model reference to the bookmarks model (BookmarksModel)
         @param parent reference to the parent widget (QWidget)
         """
         E4ModelToolBar.__init__(self, 
             QApplication.translate("BookmarksToolBar", "Bookmarks"), parent)
         
+        self.__mw = mainWindow
         self.__bookmarksModel = model
         
         self.setModel(model)
@@ -96,14 +99,19 @@ class BookmarksToolBar(E4ModelToolBar):
         """
         assert idx.isValid()
         
-        if self._keyboardModifiers & Qt.ControlModifier:
-            self.emit(SIGNAL("newUrl(const QUrl&, const QString&)"), 
-                      idx.data(BookmarksModel.UrlRole).toUrl(), 
-                      idx.data(Qt.DisplayRole).toString())
-        else:
-            self.emit(SIGNAL("openUrl(const QUrl&, const QString&)"), 
-                      idx.data(BookmarksModel.UrlRole).toUrl(), 
-                      idx.data(Qt.DisplayRole).toString())
+        if self._mouseButton == Qt.XButton1:
+            self.__mw.currentBrowser().pageAction(QWebPage.Back).trigger()
+        elif self._mouseButton == Qt.XButton2:
+            self.__mw.currentBrowser().pageAction(QWebPage.Forward).trigger()
+        elif self._mouseButton == Qt.LeftButton:
+            if self._keyboardModifiers & Qt.ControlModifier:
+                self.emit(SIGNAL("newUrl(const QUrl&, const QString&)"), 
+                          idx.data(BookmarksModel.UrlRole).toUrl(), 
+                          idx.data(Qt.DisplayRole).toString())
+            else:
+                self.emit(SIGNAL("openUrl(const QUrl&, const QString&)"), 
+                          idx.data(BookmarksModel.UrlRole).toUrl(), 
+                          idx.data(Qt.DisplayRole).toString())
     
     def __openToolBarBookmark(self):
         """
