@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,6 +41,9 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         self.setupUi(self)
         self.setAttribute(Qt.WA_DeleteOnClose)
         
+        self.__windowTitleTemplate = self.trUtf8("Eric4 Download %1")
+        self.setWindowTitle(self.__windowTitleTemplate.arg(""))
+        
         self.__tryAgainButton = \
             self.buttonBox.addButton(self.trUtf8("Try Again"), 
                                      QDialogButtonBox.ActionRole)
@@ -321,9 +324,12 @@ class DownloadDialog(QWidget, Ui_DownloadDialog):
         if total == -1:
             self.progressBar.setMaximum(0)
             self.progressBar.setValue(0)
+            self.setWindowTitle(self.__windowTitleTemplate.arg(""))
         else:
             self.progressBar.setMaximum(total)
             self.progressBar.setValue(received)
+            pc = "%d%%" % (received * 100 / total)
+            self.setWindowTitle(self.__windowTitleTemplate.arg(pc))
         self.__updateInfoLabel()
     
     def __updateInfoLabel(self):
