@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -79,10 +79,10 @@ class JavaScriptEricObject(QObject):
     """
     # these must be in line with the strings used by the javascript part of the start page
     translations = [
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Welcome to Eric Web Browser!"), 
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Eric Web Browser"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "Welcome to eric4 Web Browser!"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "eric4 Web Browser"), 
         QT_TRANSLATE_NOOP("JavaScriptEricObject", "Search!"), 
-        QT_TRANSLATE_NOOP("JavaScriptEricObject", "About Eric"), 
+        QT_TRANSLATE_NOOP("JavaScriptEricObject", "About eric4"), 
     ]
     
     def __init__(self, mw, parent = None):
@@ -183,9 +183,12 @@ class HelpWebPage(QWebPage):
         
         @param request reference to the network request object (QNetworkRequest)
         """
-        request.setAttribute(QNetworkRequest.User + 100, QVariant(self))
-        request.setAttribute(QNetworkRequest.User + 101, 
-                             QVariant(self.__lastRequestType))
+        try:
+            request.setAttribute(QNetworkRequest.User + 100, QVariant(self))
+            request.setAttribute(QNetworkRequest.User + 101, 
+                                 QVariant(self.__lastRequestType))
+        except TypeError:
+            pass
     
     def pageAttributeId(self):
         """
@@ -256,6 +259,17 @@ class HelpWebPage(QWebPage):
             pass
         
         return QWebPage.extension(self, extension, option, output)
+    
+    def userAgentForUrl(self, url):
+        """
+        Protected method to determine the user agent for the given URL.
+        
+        @param url URL to determine user agent for (QUrl)
+        @return user agent string (string)
+        """
+        agentList = QWebPage.userAgentForUrl(self, url).split(" ")
+        agentList[0] = "Mozilla/9.0"
+        return agentList.join(" ")
 
 ##########################################################################################
 
@@ -348,6 +362,8 @@ class HelpBrowser(QWebView):
         if frame is None:
             # called from QWebFrame.javaScriptWindowObjectCleared
             frame = self.sender()
+            if isinstance(frame, HelpWebPage):
+                frame = frame.mainFrame()
             if frame.url().scheme() == "pyrc" and frame.url().path() == "home":
                 if self.__javaScriptEricObject is None:
                     self.__javaScriptEricObject = JavaScriptEricObject(self.mw, self)
@@ -426,7 +442,7 @@ class HelpBrowser(QWebView):
             
             if not QFileInfo(name.toLocalFile()).exists():
                 QMessageBox.critical(None,
-                    self.trUtf8("Web Browser"),
+                    self.trUtf8("eric4 Web Browser"),
                     self.trUtf8("""<p>The file <b>%1</b> does not exist.</p>""")\
                         .arg(name.toLocalFile()),
                     QMessageBox.StandardButtons(\
@@ -440,7 +456,7 @@ class HelpBrowser(QWebView):
                 started = QDesktopServices.openUrl(name)
                 if not started:
                     KQMessageBox.critical(self,
-                        self.trUtf8("Web Browser"),
+                        self.trUtf8("eric4 Web Browser"),
                         self.trUtf8("""<p>Could not start a viewer"""
                         """ for file <b>%1</b>.</p>""").arg(name.path()))
                 return
@@ -448,7 +464,7 @@ class HelpBrowser(QWebView):
             started = QDesktopServices.openUrl(name)
             if not started:
                 KQMessageBox.critical(self,
-                    self.trUtf8("Web Browser"),
+                    self.trUtf8("eric4 Web Browser"),
                     self.trUtf8("""<p>Could not start an application"""
                     """ for URL <b>%1</b>.</p>""").arg(name.toString()))
             return
@@ -465,7 +481,7 @@ class HelpBrowser(QWebView):
                 started = QDesktopServices.openUrl(name)
                 if not started:
                     KQMessageBox.critical(self,
-                        self.trUtf8("Web Browser"),
+                        self.trUtf8("eric4 Web Browser"),
                         self.trUtf8("""<p>Could not start a viewer"""
                         """ for file <b>%1</b>.</p>""").arg(name.path()))
                 return
@@ -601,6 +617,14 @@ class HelpBrowser(QWebView):
             evt.accept()
             return
         
+        if evt.modifiers() & Qt.ShiftModifier:
+            if evt.delta() < 0:
+                self.backward()
+            else:
+                self.forward()
+            evt.accept()
+            return
+        
         QWebView.wheelEvent(self, evt)
     
     def hasSelection(self):
@@ -805,6 +829,19 @@ class HelpBrowser(QWebView):
         dlg.setTitle(self.title())
         dlg.exec_()
     
+    def mousePressEvent(self, evt):
+        """
+        Protected method called by a mouse press event.
+        
+        @param evt reference to the mouse event (QMouseEvent)
+        """
+        if evt.button() == Qt.XButton1:
+            self.pageAction(QWebPage.Back).trigger()
+        elif evt.button() == Qt.XButton2:
+            self.pageAction(QWebPage.Forward).trigger()
+        else:
+            QWebView.mousePressEvent(self, evt)
+    
     def keyPressEvent(self, evt):
         """
         Protected method called by a key press.
@@ -895,7 +932,7 @@ class HelpBrowser(QWebView):
         """
         self.__isLoading = False
         self.mw.progressBar().hide()
-        self.mw.resetLoading(self)
+        self.mw.resetLoading(self, ok)
         
         self.__iconChanged()
         
