@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ import imp
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
-from PyQt4.QtWebKit import QWebSettings
+from PyQt4.QtWebKit import QWebSettings, QWebPage
 
 import UI.PixmapCache
 
@@ -23,6 +23,36 @@ from E4Gui.E4LineEdit import E4LineEdit
 from OpenSearch.OpenSearchManager import OpenSearchManager
 from OpenSearch.OpenSearchEngineAction import OpenSearchEngineAction
 
+
+class HelpWebSearchEdit(E4LineEdit):
+    """
+    Class implementing the web search line edit.
+    """
+    def __init__(self, mainWindow, parent=None):
+        """
+        Constructor
+        
+        @param mainWindow reference to the main window (HelpWindow)
+        @param parent reference to the parent widget (QWidget)
+        """
+        E4LineEdit.__init__(self, parent)
+        
+        self.__mw = mainWindow
+    
+    def mousePressEvent(self, evt):
+        """
+        Protected method called by a mouse press event.
+        
+        @param evt reference to the mouse event (QMouseEvent)
+        """
+        if evt.button() == Qt.XButton1:
+            self.__mw.currentBrowser().pageAction(QWebPage.Back).trigger()
+        elif evt.button() == Qt.XButton2:
+            self.__mw.currentBrowser().pageAction(QWebPage.Forward).trigger()
+        else:
+            E4LineEdit.mousePressEvent(self, evt)
+
+
 class HelpWebSearchWidget(QWidget):
     """
     Class implementing a web search widget for the web browser.
@@ -33,7 +63,6 @@ class HelpWebSearchWidget(QWidget):
         """
         Constructor
         
-        @param inactiveText text to be shown on inactivity (string or QString)
         @param parent reference to the parent widget (QWidget)
         """
         QWidget.__init__(self, parent)
@@ -62,7 +91,7 @@ class HelpWebSearchWidget(QWidget):
         self.__searchButton.setIcon(UI.PixmapCache.getIcon("webSearch.png"))
         self.__layout.addWidget(self.__searchButton)
         
-        self.__searchEdit = E4LineEdit(parent = self)
+        self.__searchEdit = HelpWebSearchEdit(self.mw, parent = self)
         self.__layout.addWidget(self.__searchEdit)
         
         self.__clearButton = QToolButton(self)
