@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -32,16 +32,6 @@ class OpenSearchEngine(QObject):
     @signal suggestions(const QStringList&) emitted after the suggestions have 
             been received
     """
-    loc = Preferences.getUILanguage()
-    if loc == "System":
-        loc = QLocale.system().name()
-    if loc is None:
-        _language = QString("en")
-    elif loc == "C":
-        _language = QString()
-    else:
-        _language = loc[:2]
-    
     def __init__(self, parent = None):
         """
         Constructor
@@ -79,11 +69,16 @@ class OpenSearchEngine(QObject):
         @param searchTemplate template to be parsed (string or QString)
         @return parsed template (QString)
         """
+        locale = QLocale(Preferences.getHelp("SearchLanguage"))
+        language = locale.name().split("_")[0]
+        country = language.toLower()
+        
         result = QString(searchTemplate)
         result.replace("{count}", "20")
         result.replace("{startIndex}", "0")
         result.replace("{startPage}", "0")
-        result.replace("{language}", cls._language)
+        result.replace("{language}", language)
+        result.replace("{country}", country)
         result.replace("{inputEncoding}", "UTF-8")
         result.replace("{outputEncoding}", "UTF-8")
         result.replace("{searchTerms}", QString(QUrl.toPercentEncoding(searchTerm)))
@@ -446,7 +441,7 @@ class OpenSearchEngine(QObject):
         Private slot to receive the suggestions.
         """
         buffer = str(self.__suggestionsReply.readAll())
-        response = Utilities.decode(buffer)[0]
+        response = Utilities.decodeBytes(buffer)
         response = response.strip()
         
         self.__suggestionsReply.close()
