@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -158,7 +158,7 @@ if Preferences.getUI("UseKDEDialogs") and not sys.e4nokde:
             return dlg.selectedFiles()
         
         def __kdeGetExistingDirectory(parent = None, caption = QString(), 
-                                dir_ = QString(),
+                                dir_ = QString(), 
                                 options = QFileDialog.Options(QFileDialog.ShowDirsOnly)):
             """
             Module function to get the name of a directory.
@@ -193,7 +193,7 @@ def __qtReorderFilter(filter, selectedFilter = None):
     @param selectedFilter this is set to the selected filter (QString or string)
     @return the rearranged Qt file filter (QString)
     """
-    if selectedFilter is not None:
+    if selectedFilter is not None and not Globals.isMacPlatform():
         fileFilters = QStringList(filter.split(';;'))
 ##        fileFilters.removeAll(selectedFilter)
         fileFilters.prepend(selectedFilter)
