@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -403,17 +403,17 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
         except os.error, why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(unicode(why)), \
+                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
                 False
         except IOError, why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(unicode(why)), \
+                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
                 False
         except OSError, why:
             self.__rollback()
             return False, \
-                self.trUtf8("Error installing plugin. Reason: %1").arg(unicode(why)), \
+                self.trUtf8("Error installing plugin. Reason: %1").arg(str(why)), \
                 False
         except:
             print >>sys.stderr, "Unspecific exception installing plugin."
