@@ -74,6 +74,8 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         self.__downloadCancelButton.setEnabled(False)
         self.__installButton.setEnabled(False)
         
+        self.repositoryUrlEdit.setText(Preferences.getUI("PluginRepositoryUrl"))
+        
         self.repositoryList.headerItem().setText(self.repositoryList.columnCount(), "")
         self.repositoryList.header().setSortIndicator(0, Qt.AscendingOrder)
         
@@ -176,7 +178,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         """
         Private slot to download a new list and display the contents.
         """
-        url = Preferences.getUI("PluginRepositoryUrl")
+        url = self.repositoryUrlEdit.text()
         self.__downloadFile(url, 
                             self.pluginRepositoryFile, 
                             self.__downloadRepositoryFileDone)
@@ -318,6 +320,15 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
                 self.repositoryList.resizeColumnToContents(1)
                 self.repositoryList.resizeColumnToContents(2)
                 self.__resortRepositoryList()
+                
+                url = Preferences.getUI("PluginRepositoryUrl")
+                if url != self.repositoryUrlEdit.text():
+                    self.repositoryUrlEdit.setText(url)
+                    KQMessageBox.warning(self,
+                        self.trUtf8("Plugins Repository URL Changed"),
+                        self.trUtf8("""The URL of the Plugins Repository has"""
+                                    """ changed. Select the "Update" button to get"""
+                                    """ the new repository file."""))
             else:
                 KQMessageBox.critical(None,
                     self.trUtf8("Read plugins repository file"),
@@ -564,6 +575,15 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         @return list of plugin filenames (QStringList)
         """
         return self.__pluginsDownloaded
+    
+    @pyqtSignature("bool")
+    def on_repositoryUrlEditButton_toggled(self, checked):
+        """
+        Private slot to set the read only status of the repository URL line edit.
+        
+        @param checked state of the push button (boolean)
+        """
+        self.repositoryUrlEdit.setReadOnly(not checked)
 
 class PluginRepositoryDialog(QDialog):
     """
