@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -61,6 +61,7 @@ Xia WeiPeng
     Chinese translations
 
 Gianluca
+Leonardo Giordani
     Italian translations
 """
 )
@@ -750,7 +751,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         self.setupUi(self)
         
         self.ericLabel.setText(titleText)
-        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric.png"))
+        self.ericPixmap.setPixmap(UI.PixmapCache.getPixmap("eric.png").scaled(48, 48))
         
         ####################################################################
         ## ABOUT        
