@@ -63,9 +63,12 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @param error error text (string or QString)
         @param sourcecode faulty line of code (string)
         """
-        itm = QTreeWidgetItem(self.resultList, QStringList() \
-            << file << str(line) << error << sourcecode)
+        itm = QTreeWidgetItem(self.resultList)
         itm.setTextAlignment(1, Qt.AlignRight)
+        itm.setData(0, Qt.DisplayRole, file)
+        itm.setData(1, Qt.DisplayRole, line)
+        itm.setData(2, Qt.DisplayRole, error)
+        itm.setData(3, Qt.DisplayRole, sourcecode)
         itm.setData(0, Qt.UserRole, QVariant(int(index)))
         
     def start(self, fn, codestring = ""):
