@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,7 +48,7 @@ def exeDisplayData():
     @return dictionary containing the data to query the presence of
         the executable
     """
-    exe = 'eric4-doc'
+    exe = 'eric4_doc'
     if Utilities.isWindowsPlatform():
         exe = os.path.join(getConfig("bindir"), exe +'.bat')
     
@@ -58,7 +58,7 @@ def exeDisplayData():
                                 "Eric4 Documentation Generator"), 
         "exe"               : exe, 
         "versionCommand"    : '--version', 
-        "versionStartsWith" : 'eric4-', 
+        "versionStartsWith" : 'eric4_', 
         "versionPosition"   : -2, 
         "version"           : "", 
         "versionCleanup"    : None, 
@@ -95,14 +95,14 @@ class EricdocPlugin(QObject):
         menu = e4App().getObject("Project").getMenu("Apidoc")
         if menu:
             self.__projectAct = \
-                E4Action(self.trUtf8('Generate documentation (eric4-doc)'),
-                    self.trUtf8('Generate &documentation (eric4-doc)'), 0, 0,
+                E4Action(self.trUtf8('Generate documentation (eric4_doc)'),
+                    self.trUtf8('Generate &documentation (eric4_doc)'), 0, 0,
                     self, 'doc_eric4_doc')
             self.__projectAct.setStatusTip(\
-                self.trUtf8('Generate API documentation using eric4-doc'))
+                self.trUtf8('Generate API documentation using eric4_doc'))
             self.__projectAct.setWhatsThis(self.trUtf8(
                 """<b>Generate documentation</b>"""
-                """<p>Generate API documentation using eric4-doc.</p>"""
+                """<p>Generate API documentation using eric4_doc.</p>"""
             ))
             self.connect(self.__projectAct, SIGNAL('triggered()'), self.__doEricdoc)
             e4App().getObject("Project").addE4Actions([self.__projectAct])
@@ -142,11 +142,11 @@ class EricdocPlugin(QObject):
     
     def __doEricdoc(self):
         """
-        Private slot to perform the eric4-doc api documentation generation.
+        Private slot to perform the eric4_doc api documentation generation.
         """
         project = e4App().getObject("Project")
         parms = project.getData('DOCUMENTATIONPARMS', "ERIC4DOC")
-        dlg = EricdocConfigDialog(project.getProjectPath(), parms)
+        dlg = EricdocConfigDialog(project, parms)
         if dlg.exec_() == QDialog.Accepted:
             args, parms = dlg.generateParameters()
             project.setData('DOCUMENTATIONPARMS', "ERIC4DOC", parms)
@@ -159,10 +159,10 @@ class EricdocPlugin(QObject):
             
             outdir = parms['outputDirectory']
             if outdir == '':
-                outdir = 'doc'      # that is eric4-docs default output dir
+                outdir = 'doc'      # that is eric4_docs default output dir
                 
             # add it to the project data, if it isn't in already
-            outdir = outdir.replace(project.ppath+os.sep, '')
+            outdir = project.getRelativePath(outdir)
             if outdir not in project.pdata['OTHERS']:
                 project.pdata['OTHERS'].append(outdir)
                 project.setDirty(True)
@@ -171,10 +171,10 @@ class EricdocPlugin(QObject):
             if parms['qtHelpEnabled']:
                 outdir = parms['qtHelpOutputDirectory']
                 if outdir == '':
-                    outdir = 'help'      # that is eric4-docs default QtHelp output dir
+                    outdir = 'help'      # that is eric4_docs default QtHelp output dir
                     
                 # add it to the project data, if it isn't in already
-                outdir = outdir.replace(project.ppath+os.sep, '')
+                outdir = project.getRelativePath(outdir)
                 if outdir not in project.pdata['OTHERS']:
                     project.pdata['OTHERS'].append(outdir)
                     project.setDirty(True)
