@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -862,7 +862,7 @@ class SvnProjectBrowserHelper(VcsProjectBrowserHelper):
             name = unicode(self.browser.currentItem().fileName())
         except AttributeError:
             name = unicode(self.browser.currentItem().dirName())
-        name = name.replace(self.project.ppath+os.sep, "")
+        name = self.project.getRelativePath(name)
         self.vcs.svnInfo(self.project.ppath, name)
         
     def __SVNConfigure(self):
