@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -187,8 +187,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
         cwd = os.getcwd()
         os.chdir(dname)
         try:
-            ppath = e4App().getObject('Project').getProjectPath()
-            dname = dname.replace(ppath, '')
+            dname = e4App().getObject('Project').getRelativePath(dname)
             if dname:
                 dname += "/"
             for name in fnames:
@@ -354,7 +353,7 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
             KQMessageBox.critical(self, self.trUtf8('Save Diff'),
                 self.trUtf8('<p>The patch file <b>%1</b> could not be saved.'
                     '<br>Reason: %2</p>')
-                    .arg(unicode(fname)).arg(unicode(why)))
+                    .arg(unicode(fname)).arg(str(why)))
         
     def __showError(self, msg):
         """
