@@ -66,7 +66,8 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
         self.flags = {
             'A' : self.trUtf8('Added'),
             'D' : self.trUtf8('Deleted'),
-            'M' : self.trUtf8('Modified')
+            'M' : self.trUtf8('Modified'),
+            'R' : self.trUtf8('Replaced'),
         }
         
         self.diff = None
@@ -140,19 +141,18 @@ class SvnLogBrowserDialog(QDialog, SvnDialogMixin, Ui_SvnLogBrowserDialog):
             rev = ""
             self.__lastRev = 0
         else:
-            rev = "%7d" % revision.number
+            rev = revision.number
             self.__lastRev = revision.number
         if date == "":
             dt = ""
         else:
             dt = formatTime(date)
         
-        itm = QTreeWidgetItem(self.logTree, QStringList() \
-            << rev \
-            << author \
-            << dt \
-            << " ".join(message.splitlines())
-        )
+        itm = QTreeWidgetItem(self.logTree)
+        itm.setData(0, Qt.DisplayRole, rev)
+        itm.setData(1, Qt.DisplayRole, author)
+        itm.setData(2, Qt.DisplayRole, dt)
+        itm.setData(3, Qt.DisplayRole, " ".join(message.splitlines()))
         
         changes = []
         for changedPath in changedPaths:
