@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -103,8 +103,6 @@ class SvnOptionsDialog(QDialog, Ui_SvnOptionsDialog):
         """
         scheme = str(self.protocolCombo.currentText())
         url = unicode(self.vcsUrlEdit.text())
-        if scheme == "file://" and url[0] not in ["\\", "/"]:
-            url = "/%s" % url
         vcsdatadict = {
             "url" : '%s%s' % (scheme, url),
             "message" : unicode(self.vcsLogEdit.text()),
