@@ -189,22 +189,20 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
         @param path path of the file or directory (string or QString)
         """
         statusText = self.trUtf8(svnStatusMap[status])
-        itm = QTreeWidgetItem(self.statusList, 
-            QStringList() \
-            << "" \
-            << changelist \
-            << statusText \
-            << self.trUtf8(svnStatusMap[propStatus]) \
-            << self.yesno[locked] \
-            << self.yesno[history] \
-            << self.yesno[switched] \
-            << self.lockinfo[lockinfo] \
-            << self.yesno[uptodate] \
-            << "%7s" % str(revision) \
-            << "%7s" % str(change) \
-            << author \
-            << path
-        )
+        itm = QTreeWidgetItem(self.statusList)
+        itm.setData(0, Qt.DisplayRole, "")
+        itm.setData(1, Qt.DisplayRole, changelist)
+        itm.setData(2, Qt.DisplayRole, statusText)
+        itm.setData(3, Qt.DisplayRole, self.trUtf8(svnStatusMap[propStatus]))
+        itm.setData(4, Qt.DisplayRole, self.yesno[locked])
+        itm.setData(5, Qt.DisplayRole, self.yesno[history])
+        itm.setData(6, Qt.DisplayRole, self.yesno[switched])
+        itm.setData(7, Qt.DisplayRole, self.lockinfo[lockinfo])
+        itm.setData(8, Qt.DisplayRole, self.yesno[uptodate])
+        itm.setData(9, Qt.DisplayRole, revision)
+        itm.setData(10, Qt.DisplayRole, change)
+        itm.setData(11, Qt.DisplayRole, author)
+        itm.setData(12, Qt.DisplayRole, path)
         
         itm.setTextAlignment(1, Qt.AlignLeft)
         itm.setTextAlignment(2, Qt.AlignHCenter)
@@ -303,9 +301,11 @@ class SvnStatusDialog(QWidget, SvnDialogMixin, Ui_SvnStatusDialog):
                 for file in allFiles:
                     uptodate = True
                     if file.repos_text_status != pysvn.wc_status_kind.none:
-                        uptodate = uptodate and file.repos_text_status == file.text_status
+                        uptodate = uptodate and \
+                            file.repos_text_status != pysvn.wc_status_kind.modified
                     if file.repos_prop_status != pysvn.wc_status_kind.none:
-                        uptodate = uptodate and file.repos_prop_status == file.prop_status
+                        uptodate = uptodate and \
+                            file.repos_prop_status != pysvn.wc_status_kind.modified
                     
                     lockState = " "
                     if file.entry is not None and \
