@@ -2205,11 +2205,13 @@ class Subversion(VersionControl):
         @param url url string (string)
         @return properly normalized url for subversion
         """
+        protocol, url = url.split("://")
+        if url.startswith("\\\\"):
+            url = url[2:]
         url = url.replace('\\', '/')
         if url.endswith('/'):
             url = url[:-1]
-        urll = url.split('//')
-        return "%s//%s" % (urll[0], '/'.join(urll[1:]))
+        return "%s://%s" % (protocol, url)
 
     ############################################################################
     ## Methods to get the helper objects are below.
