@@ -97,6 +97,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -105,6 +106,7 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
         
     def __finish(self):
         """
@@ -119,8 +121,10 @@ class SvnBlameDialog(QDialog, Ui_SvnBlameDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
         
         self.process = None
         
