@@ -60,9 +60,15 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
         
         self.proc = None
         
+        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
+        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
+        
         if Preferences.getVCS("AutoClose") and \
            self.normal and \
            not self.errors.toPlainText().length() > 0:
@@ -132,6 +138,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
         if not procStarted:
             self.buttonBox.setFocus()
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -140,6 +147,7 @@ class SvnDialog(QDialog, Ui_SvnDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
         return procStarted
         
     def normalExit(self):
