@@ -98,6 +98,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             (only valid for URL diffs) (boolean)
         """
         self.errorGroup.hide()
+        self.inputGroup.show()
         self.intercept = False
         self.filename = fn
         
@@ -166,6 +167,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -181,6 +183,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         @param exitStatus exit status of the process (QProcess.ExitStatus)
         """
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
         
         if self.paras == 0:
             self.contents.insertPlainText(\
@@ -188,6 +191,9 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             return
             
         self.buttonBox.button(QDialogButtonBox.Save).setEnabled(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
+        
         tc = self.contents.textCursor()
         tc.movePosition(QTextCursor.Start)
         self.contents.setTextCursor(tc)
