@@ -87,7 +87,8 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.flags = {
             'A' : self.trUtf8('Added'),
             'D' : self.trUtf8('Deleted'),
-            'M' : self.trUtf8('Modified')
+            'M' : self.trUtf8('Modified'),
+            'R' : self.trUtf8('Replaced'),
         }
         
         self.buf = QStringList()        # buffer for stdout
@@ -156,12 +157,11 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         for line in message:
             msg.append(line.trimmed())
         
-        itm = QTreeWidgetItem(self.logTree, QStringList() \
-            << "%7s" % revision \
-            << author \
-            << date \
-            << msg.join(" ")
-        )
+        itm = QTreeWidgetItem(self.logTree)
+        itm.setData(0, Qt.DisplayRole, int(revision))
+        itm.setData(1, Qt.DisplayRole, author)
+        itm.setData(2, Qt.DisplayRole, date)
+        itm.setData(3, Qt.DisplayRole, msg.join(" "))
         
         itm.setData(0, self.__messageRole, QVariant(message))
         itm.setData(0, self.__changesRole, QVariant(repr(changedPaths)))
@@ -237,10 +237,14 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         
         self.process.setWorkingDirectory(self.dname)
         
+        self.inputGroup.setEnabled(True)
+        self.inputGroup.show()
+        
         self.process.start('svn', args)
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -291,6 +295,7 @@ class SvnLogBrowserDialog(QDialog, Ui_SvnLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
         
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
     
     def __processBuffer(self):
         """
