@@ -126,8 +126,6 @@ class SvnNewProjectOptionsDialog(QDialog, Ui_SvnNewProjectOptionsDialog):
         """
         scheme = str(self.protocolCombo.currentText())
         url = unicode(self.vcsUrlEdit.text())
-        if scheme == "file://" and url[0] not in ["\\", "/"]:
-            url = "/%s" % url
         vcsdatadict = {
             "url" : '%s%s' % (scheme, url),
             "tag" : unicode(self.vcsTagEdit.text()),
