@@ -34,6 +34,9 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
         self.process = QProcess()
+        env = QProcessEnvironment.systemEnvironment()
+        env.insert("LANG", "C")
+        self.process.setProcessEnvironment(env)
         self.vcs = vcs
         
         self.propsList.headerItem().setText(self.propsList.columnCount(), "")
@@ -47,7 +50,7 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
             self.__readStderr)
         
         self.rx_path = QRegExp(r"Properties on '([^']+)':\s*")
-        self.rx_prop = QRegExp(r"  (.*) : (.*)[\r\n]")
+        self.rx_prop = QRegExp(r"  (.*) *: *(.*)[\r\n]")
         self.lastPath = None
         self.lastProp = None
         self.propBuffer = QString('')
@@ -74,7 +77,8 @@ class SvnPropListDialog(QWidget, Ui_SvnPropListDialog):
         @param propName name of the property (string or QString)
         @param propValue value of the property (string or QString)
         """
-        QTreeWidgetItem(self.propsList, QStringList() << path << propName << propValue)
+        QTreeWidgetItem(self.propsList,
+            QStringList() << path << propName << propValue.trimmed())
         
     def closeEvent(self, e):
         """
