@@ -170,10 +170,10 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         }
         
         self.rx_status = \
-            QRegExp('(.{8})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
+            QRegExp('(.{8,9})\\s+([0-9-]+)\\s+([0-9?]+)\\s+([\\w?]+)\\s+(.+)\\s*')
             # flags (8 anything), revision, changed rev, author, path
         self.rx_status2 = \
-            QRegExp('(.{8})\\s+(.+)\\s*')
+            QRegExp('(.{8,9})\\s+(.+)\\s*')
             # flags (8 anything), path
         self.rx_changelist = \
             QRegExp('--- \\S+ .([\\w\\s]+).:\\s+')
@@ -223,23 +223,36 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
            self.currentChangelist == "":
             return
         
+        if revision == "":
+            rev = ""
+        else:
+            try:
+                rev = int(revision)
+            except ValueError:
+                rev = revision
+        if change == "":
+            chg = ""
+        else:
+            try:
+                chg = int(change)
+            except ValueError:
+                chg = change
         statusText = self.status[status]
-        itm = QTreeWidgetItem(self.statusList, 
-            QStringList() \
-            << "" \
-            << self.currentChangelist \
-            << statusText \
-            << self.propStatus[propStatus] \
-            << self.locked[locked] \
-            << self.history[history] \
-            << self.switched[switched] \
-            << self.lockinfo[lockinfo] \
-            << self.uptodate[uptodate] \
-            << "%7s" % str(revision) \
-            << "%7s" % str(change) \
-            << author \
-            << path
-        )
+        
+        itm = QTreeWidgetItem(self.statusList)
+        itm.setData(0, Qt.DisplayRole, "")
+        itm.setData(1, Qt.DisplayRole, self.currentChangelist)
+        itm.setData(2, Qt.DisplayRole, statusText)
+        itm.setData(3, Qt.DisplayRole, self.propStatus[propStatus])
+        itm.setData(4, Qt.DisplayRole, self.locked[locked])
+        itm.setData(5, Qt.DisplayRole, self.history[history])
+        itm.setData(6, Qt.DisplayRole, self.switched[switched])
+        itm.setData(7, Qt.DisplayRole, self.lockinfo[lockinfo])
+        itm.setData(8, Qt.DisplayRole, self.uptodate[uptodate])
+        itm.setData(9, Qt.DisplayRole, rev)
+        itm.setData(10, Qt.DisplayRole, chg)
+        itm.setData(11, Qt.DisplayRole, author)
+        itm.setData(12, Qt.DisplayRole, path)
         
         itm.setTextAlignment(1, Qt.AlignLeft)
         itm.setTextAlignment(2, Qt.AlignHCenter)
@@ -354,6 +367,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -362,6 +376,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
         
     def __finish(self):
         """
@@ -376,8 +391,10 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
         self.refreshButton.setEnabled(True)
         
         self.__statusFilters.sort()
@@ -452,13 +469,13 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
                     path = self.rx_status.cap(5).trimmed()
                     
                     self.__generateItem(flags[0], flags[1], flags[2], flags[3], flags[4], 
-                                        flags[5], flags[7], rev, change, author, path)
+                                        flags[5], flags[-1], rev, change, author, path)
                 elif self.rx_status2.exactMatch(s):
                     flags = str(self.rx_status2.cap(1))
                     path = self.rx_status2.cap(2).trimmed()
                     
                     self.__generateItem(flags[0], flags[1], flags[2], flags[3], flags[4], 
-                                        flags[5], flags[7], "", "", "", path)
+                                        flags[5], flags[-1], "", "", "", path)
                 elif self.rx_changelist.exactMatch(s):
                     self.currentChangelist = self.rx_changelist.cap(1)
                     self.changelistFound = True
@@ -536,6 +553,7 @@ class SvnStatusDialog(QWidget, Ui_SvnStatusDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
         self.inputGroup.setEnabled(True)
+        self.inputGroup.show()
         self.refreshButton.setEnabled(False)
         
         self.statusList.clear()
