@@ -144,6 +144,7 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         procStarted = self.process.waitForStarted()
         if not procStarted:
             self.inputGroup.setEnabled(False)
+            self.inputGroup.hide()
             KQMessageBox.critical(None,
                 self.trUtf8('Process Generation Error'),
                 self.trUtf8(
@@ -152,6 +153,7 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
                 ).arg('svn'))
         else:
             self.inputGroup.setEnabled(True)
+            self.inputGroup.show()
         
     def __finish(self):
         """
@@ -166,8 +168,10 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+        self.buttonBox.button(QDialogButtonBox.Close).setFocus(Qt.OtherFocusReason)
         
         self.inputGroup.setEnabled(False)
+        self.inputGroup.hide()
         
         self.process = None
         
@@ -217,8 +221,11 @@ class SvnTagBranchListDialog(QDialog, Ui_SvnTagBranchListDialog):
         @param date date of the tag (string or QString)
         @param name name (path) of the tag (string or QString)
         """
-        itm = QTreeWidgetItem(self.tagList, 
-            QStringList() << revision << author << date << name)
+        itm = QTreeWidgetItem(self.tagList)
+        itm.setData(0, Qt.DisplayRole, int(revision))
+        itm.setData(1, Qt.DisplayRole, author)
+        itm.setData(2, Qt.DisplayRole, date)
+        itm.setData(3, Qt.DisplayRole, name)
         itm.setTextAlignment(0, Qt.AlignRight)
         
     def __readStdout(self):
