@@ -939,7 +939,7 @@ class Subversion(VersionControl):
         args.append('revert')
         self.addArguments(args, self.options['global'])
         if type(name) is types.ListType:
-            if len(name) == 1 and os.path.isdir(name):
+            if len(name) == 1 and os.path.isdir(name[0]):
                 args.append('--recursive')
             self.addArguments(args, name)
         else:
@@ -1974,11 +1974,13 @@ class Subversion(VersionControl):
         @param url url string (string)
         @return properly normalized url for subversion
         """
+        protocol, url = url.split("://")
+        if url.startswith("\\\\"):
+            url = url[2:]
         url = url.replace('\\', '/')
         if url.endswith('/'):
             url = url[:-1]
-        urll = url.split('//')
-        return "%s//%s" % (urll[0], '/'.join(urll[1:]))
+        return "%s://%s" % (protocol, url)
 
     ############################################################################
     ## Methods to get the helper objects are below.
