@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -24,6 +24,7 @@ from E4Gui.E4TabWidget import E4TabWidget, E4WheelTabBar
 from E4Gui.E4Led import E4Led
 
 import Preferences
+from Globals import isMacPlatform
 
 from eric4config import getConfig
 
@@ -77,10 +78,10 @@ class TabBar(E4WheelTabBar):
             index = self.tabAt(event.pos())
             mimeData.setText(self.tabText(index))
             mimeData.setData("action", "tab-reordering")
-            mimeData.setData("tabbar-id", QByteArray.number(id(self)))
+            mimeData.setData("tabbar-id", str(id(self)))
             mimeData.setData("source-index", 
                              QByteArray.number(self.tabAt(self.__dragStartPos)))
-            mimeData.setData("tabwidget-id", QByteArray.number(id(self.parentWidget())))
+            mimeData.setData("tabwidget-id", str(id(self.parentWidget())))
             drag.setMimeData(mimeData)
             if event.modifiers() == Qt.KeyboardModifiers(Qt.ShiftModifier):
                 drag.exec_(Qt.DropActions(Qt.CopyAction))
@@ -111,11 +112,11 @@ class TabBar(E4WheelTabBar):
         @param event reference to the drop event (QDropEvent)
         """
         mimeData = event.mimeData()
-        oldID = mimeData.data("tabbar-id").toLong()[0]
+        oldID = long(mimeData.data("tabbar-id"))
         fromIndex = mimeData.data("source-index").toInt()[0]
         toIndex = self.tabAt(event.pos())
         if oldID != id(self):
-            parentID = mimeData.data("tabwidget-id").toLong()[0]
+            parentID = long(mimeData.data("tabwidget-id"))
             if event.proposedAction() == Qt.MoveAction:
                 self.emit(SIGNAL("tabRelocateRequested(long, int, int)"), 
                           parentID, fromIndex, toIndex)
@@ -150,6 +151,11 @@ class TabWidget(E4TabWidget):
         self.__tabBar = TabBar(self)
         self.setTabBar(self.__tabBar)
         
+        self.setUsesScrollButtons(True)
+        self.setElideMode(Qt.ElideNone)
+        if isMacPlatform():
+            self.setDocumentMode(True)
+        
         self.connect(self.__tabBar, SIGNAL("tabMoveRequested(int, int)"), 
                      self.moveTab)
         self.connect(self.__tabBar, SIGNAL("tabRelocateRequested(long, int, int)"), 
@@ -245,12 +251,12 @@ class TabWidget(E4TabWidget):
             self.trUtf8('Save As...'), self.__contextMenuSaveAs)
         self.__menu.addAction(UI.PixmapCache.getIcon("fileSaveAll.png"),
             self.trUtf8('Save All'), self.__contextMenuSaveAll)
-        self.projectMenuAct = \
-            self.__menu.addAction(UI.PixmapCache.getIcon("fileSaveProject.png"),
-                self.trUtf8('Save to Project'), self.__contextMenuSaveToProject)
         self.__menu.addSeparator()
         self.__menu.addAction(UI.PixmapCache.getIcon("print.png"),
             self.trUtf8('Print'), self.__contextMenuPrintFile)
+        self.__menu.addSeparator()
+        self.copyPathAct = self.__menu.addAction(self.trUtf8("Copy Path to Clipboard"), 
+            self.__contextMenuCopyPathToClipboard)
         
     def __showContextMenu(self, coord, index):
         """
@@ -263,7 +269,7 @@ class TabWidget(E4TabWidget):
             self.contextMenuEditor = self.widget(index)
             if self.contextMenuEditor:
                 self.saveMenuAct.setEnabled(self.contextMenuEditor.isModified())
-            self.projectMenuAct.setEnabled(e4App().getObject("Project").isOpen())
+                self.copyPathAct.setEnabled(bool(self.contextMenuEditor.getFileName()))
             
             self.contextMenuIndex = index
             self.leftMenuAct.setEnabled(index > 0)
@@ -372,10 +378,7 @@ class TabWidget(E4TabWidget):
             if Preferences.getUI("TabViewManagerFilenameOnly"):
                 txt = os.path.basename(fn)
             else:
-                txt = fn
-                ppath = e4App().getObject("Project").getProjectPath()
-                if ppath:
-                    txt = txt.replace(ppath + os.sep, "")
+                txt = e4App().getObject("Project").getRelativePath(fn)
             
             maxFileNameChars = Preferences.getUI("TabViewManagerFilenameLength")
             if len(txt) > maxFileNameChars:
@@ -544,13 +547,6 @@ class TabWidget(E4TabWidget):
         """
         self.vm.saveEditorsList(self.editors)
         
-    def __contextMenuSaveToProject(self):
-        """
-        Private method to save the selected tab to the current project.
-        """
-        if self.contextMenuEditor:
-            self.vm.saveEditorToProjectEd(self.contextMenuEditor)
-        
     def __contextMenuPrintFile(self):
         """
         Private method to print the selected tab.
@@ -558,6 +554,16 @@ class TabWidget(E4TabWidget):
         if self.contextMenuEditor:
             self.vm.printEditor(self.contextMenuEditor)
         
+    def __contextMenuCopyPathToClipboard(self):
+        """
+        Private method to copy the file name of the editor to the clipboard.
+        """
+        if self.contextMenuEditor:
+            fn = self.contextMenuEditor.getFileName()
+            if fn:
+                cb = QApplication.clipboard()
+                cb.setText(fn)
+        
     def __contextMenuMoveLeft(self):
         """
         Private method to move a tab one position to the left.
@@ -733,10 +739,7 @@ class Tabview(QSplitter, ViewManager):
             if self.filenameOnly:
                 txt = os.path.basename(fn)
             else:
-                txt = fn
-                ppath = e4App().getObject("Project").getProjectPath()
-                if ppath:
-                    txt = txt.replace(ppath + os.sep, "")
+                txt = e4App().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...%s" % txt[-self.maxFileNameChars:]
             if not QFileInfo(fn).isWritable():
@@ -773,10 +776,7 @@ class Tabview(QSplitter, ViewManager):
             if self.filenameOnly:
                 txt = os.path.basename(fn)
             else:
-                txt = fn
-                ppath = e4App().getObject("Project").getProjectPath()
-                if ppath:
-                    txt = txt.replace(ppath + os.sep, "")
+                txt = e4App().getObject("Project").getRelativePath(fn)
             if len(txt) > self.maxFileNameChars:
                 txt = "...%s" % txt[-self.maxFileNameChars:]
             if not QFileInfo(fn).isWritable():
@@ -844,10 +844,7 @@ class Tabview(QSplitter, ViewManager):
         if self.filenameOnly:
             tabName = os.path.basename(unicode(newName))
         else:
-            tabName = unicode(newName)
-            ppath = e4App().getObject("Project").getProjectPath()
-            if ppath:
-                tabName = tabName.replace(ppath + os.sep, "")
+            tabName = e4App().getObject("Project").getRelativePath(newName)
         if len(tabName) > self.maxFileNameChars:
             tabName = "...%s" % tabName[-self.maxFileNameChars:]
         index = self.currentTabWidget.indexOf(editor)
@@ -1074,10 +1071,7 @@ class Tabview(QSplitter, ViewManager):
                         if self.filenameOnly:
                             txt = os.path.basename(fn)
                         else:
-                            txt = fn
-                            ppath = e4App().getObject("Project").getProjectPath()
-                            if ppath:
-                                txt = txt.replace(ppath + os.sep, "")
+                            txt = e4App().getObject("Project").getRelativePath(fn)
                         if len(txt) > self.maxFileNameChars:
                             txt = "...%s" % txt[-self.maxFileNameChars:]
                         if not QFileInfo(fn).isWritable():
