@@ -57,6 +57,8 @@ class ConfigurationWidget(QWidget):
     Class implementing a dialog for the configuration of eric4.
     
     @signal preferencesChanged emitted after settings have been changed
+    @signal accepted() emitted to indicate acceptance of the changes
+    @signal rejected() emitted to indicate rejection of the changes
     """
     DefaultMode     = 0
     HelpBrowserMode = 1
@@ -294,9 +296,6 @@ class ConfigurationWidget(QWidget):
                     [self.trUtf8("Help Documentation"), 
                     "preferences-helpdocumentation.png",
                     "HelpDocumentationPage", "0helpPage", None],
-                "helpViewersPage" : \
-                    [self.trUtf8("Help Viewers"), "preferences-helpviewers.png",
-                    "HelpViewersPage", "0helpPage", None],
                 "helpWebBrowserPage" : \
                     [self.trUtf8("eric4 Web Browser"), "ericWeb.png",
                     "HelpWebBrowserPage", "0helpPage", None],
@@ -337,10 +336,22 @@ class ConfigurationWidget(QWidget):
             self.__showConfigurationPage)
         self.connect(self.configList, SIGNAL("itemClicked(QTreeWidgetItem *, int)"),
             self.__showConfigurationPage)
+        self.connect(self.buttonBox, SIGNAL("accepted()"), self.accept)
+        self.connect(self.buttonBox, SIGNAL("rejected()"), self, SIGNAL("rejected()"))
         
         if displayMode != ConfigurationWidget.TrayStarterMode:
             self.__initLexers()
         
+    def accept(self):
+        """
+        Public slot to accept the buttonBox accept signal.
+        """
+        wdg = self.focusWidget()
+        if wdg == self.configList:
+            return
+        
+        self.emit(SIGNAL("accepted()"))
+        
     def __setupUi(self):
         """
         Private method to perform the general setup of the configuration widget.
@@ -648,8 +659,8 @@ class ConfigurationDialog(QDialog):
         self.layout.addWidget(self.cw)
         self.resize(size)
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
+        self.connect(self.cw, SIGNAL("accepted()"), self.accept)
+        self.connect(self.cw, SIGNAL("rejected()"), self.reject)
         self.connect(self.cw, SIGNAL('preferencesChanged'), 
                      self.__preferencesChanged)
         
@@ -690,8 +701,8 @@ class ConfigurationWindow(KQMainWindow):
         self.setCentralWidget(self.cw)
         self.resize(size)
         
-        self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
+        self.connect(self.cw, SIGNAL("accepted()"), self.accept)
+        self.connect(self.cw, SIGNAL("rejected()"), self.close)
         
     def showConfigurationPageByName(self, pageName):
         """
