@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Debugger Python configuration page.
 """
 
-from PyQt4.QtCore import QString, pyqtSignature
+from PyQt4.QtCore import QDir, QString, pyqtSignature
 
 from KdeQt import KQFileDialog
 
@@ -103,7 +103,7 @@ class DebuggerPythonPage(ConfigurationPageBase, Ui_DebuggerPythonPage):
             None,
             self.trUtf8("Select Debug Client"),
             self.debugClientEdit.text(),
-            self.trUtf8("Python Files (*.py *.py2)"))
+            self.trUtf8("Python Files (*.py)"))
             
         if not file.isEmpty():
             self.debugClientEdit.setText(\
