@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,7 +9,7 @@ Module implementing the Editor APIs configuration page.
 
 from PyQt4.QtCore import QDir, QString, QStringList, pyqtSignature, SIGNAL, QFileInfo
 
-from KdeQt import KQFileDialog, KQInputDialog
+from KdeQt import KQFileDialog, KQInputDialog, KQMessageBox
 from KdeQt.KQApplication import e4App
 
 from E4Gui.E4Completers import E4FileCompleter
@@ -177,6 +177,10 @@ class EditorAPIsPage(ConfigurationPageBase, Ui_EditorAPIsPage):
                 self.apiList.addItem(Utilities.toNativeSeparators(\
                     QFileInfo(QDir(installedAPIFilesPath), file).absoluteFilePath()))
         else:
+            KQMessageBox.warning(self,
+                self.trUtf8("Add from installed APIs"),
+                self.trUtf8("""There are no APIs installed yet."""
+                            """ Selection is not available."""))
             self.addInstalledApiFileButton.setEnabled(False)
         
     @pyqtSignature("")
