@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -63,6 +63,17 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
                 Preferences.getEditor("CppDollarsAllowed"))
         else:
             self.cppDollarAllowedCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.cppStylePreprocessorCheckBox.setChecked(
+                Preferences.getEditor("CppStylePreprocessor"))
+        else:
+            self.cppStylePreprocessorCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020600:
+            self.cppHighlightTripleQuotedCheckBox.setChecked(
+                Preferences.getEditor("CppHighlightTripleQuotedStrings"))
+        else:
+            self.cppHighlightTripleQuotedCheckBox.setEnabled(False)
+        
         
         # CSS
         self.foldCssCommentCheckBox.setChecked(\
@@ -91,6 +102,14 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         else:
             self.foldHtmlScriptCommentsCheckBox.setEnabled(False)
             self.foldHtmlScriptHereDocsCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.htmlDjangoCheckBox.setChecked(
+                Preferences.getEditor("HtmlDjangoTemplates"))
+            self.htmlMakoCheckBox.setChecked(
+                Preferences.getEditor("HtmlMakoTemplates"))
+        else:
+            self.htmlDjangoCheckBox.setEnabled(False)
+            self.htmlMakoCheckBox.setEnabled(False)
         
         # Pascal
         if "Pascal" in self.languages:
@@ -118,6 +137,11 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         else:
             self.foldPerlPackagesCheckBox.setEnabled(False)
             self.foldPerlPODBlocksCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020600:
+            self.foldPerlAtElseCheckBox.setChecked(
+                Preferences.getEditor("PerlFoldAtElse"))
+        else:
+            self.foldPerlAtElseCheckBox.setEnabled(False)
         
         # PostScript
         if "PostScript" in self.languages:
@@ -137,6 +161,13 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         self.foldPovrayDirectivesCheckBox.setChecked(\
             Preferences.getEditor("PovFoldDirectives"))
         
+        # Properties
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.propertiesInitialSpacesCheckBox.setChecked(
+                Preferences.getEditor("PropertiesInitialSpaces"))
+        else:
+            self.propertiesInitialSpacesCheckBox.setEnabled(False)
+        
         # Python
         self.foldPythonCommentCheckBox.setChecked(\
             Preferences.getEditor("PythonFoldComment"))
@@ -157,12 +188,69 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
             self.pythonV2UnicodeAllowedCheckBox.setEnabled(False)
             self.pythonV3BinaryAllowedCheckBox.setEnabled(False)
             self.pythonV3BytesAllowedCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.foldPythonQuotesCheckBox.setChecked(
+                Preferences.getEditor("PythonFoldQuotes"))
+            self.pythonStringsOverNewlineCheckBox.setChecked(
+                Preferences.getEditor("PythonStringsOverNewLineAllowed"))
+        else:
+            self.foldPythonQuotesCheckBox.setEnabled(False)
+            self.pythonStringsOverNewlineCheckBox.setEnabled(False)
+        if QSCINTILLA_VERSION() >= 0x020600:
+            self.pythonHighlightSubidentifierCheckBox.setChecked(
+                Preferences.getEditor("PythonHighlightSubidentifier"))
+        else:
+            self.pythonHighlightSubidentifierCheckBox.setEnabled(False)
+        
+        # Ruby
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.foldRubyCommentCheckBox.setChecked(
+                Preferences.getEditor("RubyFoldComment"))
+        else:
+            self.foldRubyCommentCheckBox.setEnabled(False)
         
         # SQL
         self.foldSqlCommentCheckBox.setChecked(\
             Preferences.getEditor("SqlFoldComment"))
         self.sqlBackslashEscapesCheckBox.setChecked(\
             Preferences.getEditor("SqlBackslashEscapes"))
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.sqlFoldAtElseCheckBox.setChecked(
+                Preferences.getEditor("SqlFoldAtElse"))
+            self.sqlFoldOnlyBeginCheckBox.setChecked(
+                Preferences.getEditor("SqlFoldOnlyBegin"))
+            self.sqlDottedWordsCheckBox.setChecked(
+                Preferences.getEditor("SqlDottedWords"))
+            self.sqlHashCommentsCheckBox.setChecked(
+                Preferences.getEditor("SqlHashComments"))
+            self.sqlQuotedIdentifiersCheckBox.setChecked(
+                Preferences.getEditor("SqlQuotedIdentifiers"))
+        else:
+            self.sqlFoldAtElseCheckBox.setEnabled(False)
+            self.sqlFoldOnlyBeginCheckBox.setEnabled(False)
+            self.sqlDottedWordsCheckBox.setEnabled(False)
+            self.sqlHashCommentsCheckBox.setEnabled(False)
+            self.sqlQuotedIdentifiersCheckBox.setEnabled(False)
+        
+        # TCL
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.foldTclCommentCheckBox.setChecked(
+                Preferences.getEditor("TclFoldComment"))
+        else:
+            self.foldTclCommentCheckBox.setEnabled(False)
+        
+        # TeX
+        if QSCINTILLA_VERSION() >= 0x020500:
+            self.foldTexCommentCheckBox.setChecked(
+                Preferences.getEditor("TexFoldComment"))
+            self.texProcessCommentsCheckBox.setChecked(
+                Preferences.getEditor("TexProcessComments"))
+            self.texProcessIfCheckBox.setChecked(
+                Preferences.getEditor("TexProcessIf"))
+        else:
+            self.foldTexCommentCheckBox.setEnabled(False)
+            self.texProcessCommentsCheckBox.setEnabled(False)
+            self.texProcessIfCheckBox.setEnabled(False)
         
         # VHDL
         self.vhdlFoldCommentCheckBox.setChecked(\
@@ -221,6 +309,12 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         if QSCINTILLA_VERSION() >= 0x020400:
             Preferences.setEditor("CppDollarsAllowed",
                 int(self.cppDollarAllowedCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("CppStylePreprocessor",
+                int(self.cppStylePreprocessorCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020600:
+            Preferences.setEditor("CppHighlightTripleQuotedStrings",
+                int(self.cppHighlightTripleQuotedCheckBox.isChecked()))
         
         # CSS
         Preferences.setEditor("CssFoldComment",
@@ -246,6 +340,11 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
                 int(self.foldHtmlScriptCommentsCheckBox.isChecked()))
             Preferences.setEditor("HtmlFoldScriptHeredocs",
                 int(self.foldHtmlScriptHereDocsCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("HtmlDjangoTemplates",
+                int(self.htmlDjangoCheckBox.isChecked()))
+            Preferences.setEditor("HtmlMakoTemplates",
+                int(self.htmlMakoCheckBox.isChecked()))
         
         # Pascal
         if "Pascal" in self.languages:
@@ -265,6 +364,9 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
                 int(self.foldPerlPackagesCheckBox.isChecked()))
             Preferences.setEditor("PerlFoldPODBlocks",
                 int(self.foldPerlPODBlocksCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020600:
+            Preferences.setEditor("PerlFoldAtElse",
+                int(self.foldPerlAtElseCheckBox.isChecked()))
         
         # PostScript
         if "PostScript" in self.languages:
@@ -281,6 +383,11 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
         Preferences.setEditor("PovFoldDirectives",
             int(self.foldPovrayDirectivesCheckBox.isChecked()))
         
+        # Properties
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("PropertiesInitialSpaces",
+                int(self.propertiesInitialSpacesCheckBox.isChecked()))
+        
         # Python
         Preferences.setEditor("PythonFoldComment",
             int(self.foldPythonCommentCheckBox.isChecked()))
@@ -297,12 +404,50 @@ class EditorPropertiesPage(ConfigurationPageBase, Ui_EditorPropertiesPage):
                 int(self.pythonV3BinaryAllowedCheckBox.isChecked()))
             Preferences.setEditor("PythonAllowV3Bytes",
                 int(self.pythonV3BytesAllowedCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("PythonFoldQuotes",
+                int(self.foldPythonQuotesCheckBox.isChecked()))
+            Preferences.setEditor("PythonStringsOverNewLineAllowed",
+                int(self.pythonStringsOverNewlineCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020600:
+            Preferences.setEditor("PythonHighlightSubidentifier",
+                int(self.pythonHighlightSubidentifierCheckBox.isChecked()))
+        
+        # Ruby
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("RubyFoldComment",
+                int(self.foldRubyCommentCheckBox.isChecked()))
         
         # SQL
         Preferences.setEditor("SqlFoldComment",
             int(self.foldSqlCommentCheckBox.isChecked()))
         Preferences.setEditor("SqlBackslashEscapes",
             int(self.sqlBackslashEscapesCheckBox.isChecked()))
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("SqlFoldAtElse",
+                int(self.sqlFoldAtElseCheckBox.isChecked()))
+            Preferences.setEditor("SqlFoldOnlyBegin",
+                int(self.sqlFoldOnlyBeginCheckBox.isChecked()))
+            Preferences.setEditor("SqlDottedWords",
+                int(self.sqlDottedWordsCheckBox.isChecked()))
+            Preferences.setEditor("SqlHashComments",
+                int(self.sqlHashCommentsCheckBox.isChecked()))
+            Preferences.setEditor("SqlQuotedIdentifiers",
+                int(self.sqlQuotedIdentifiersCheckBox.isChecked()))
+        
+        # TCL
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("TclFoldComment",
+                int(self.foldTclCommentCheckBox.isChecked()))
+        
+        # TeX
+        if QSCINTILLA_VERSION() >= 0x020500:
+            Preferences.setEditor("TexFoldComment",
+                int(self.foldTexCommentCheckBox.isChecked()))
+            Preferences.setEditor("TexProcessComments",
+                int(self.texProcessCommentsCheckBox.isChecked()))
+            Preferences.setEditor("TexProcessIf",
+                int(self.texProcessIfCheckBox.isChecked()))
         
         # VHDL
         Preferences.setEditor("VHDLFoldComment",
