@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Help web browser configuration page.
 """
 
-from PyQt4.QtCore import qVersion, pyqtSignature, QString
+from PyQt4.QtCore import qVersion, pyqtSignature, QString, QLocale
 
 from ConfigurationPageBase import ConfigurationPageBase
 from Ui_HelpWebBrowserPage import Ui_HelpWebBrowserPage
@@ -80,6 +80,9 @@ class HelpWebBrowserPage(ConfigurationPageBase, Ui_HelpWebBrowserPage):
         self.homePageEdit.setText(
             Preferences.getHelp("HomePage"))
         
+        self.defaultSchemeCombo.setCurrentIndex(
+            self.defaultSchemeCombo.findText(
+                Preferences.getHelp("DefaultScheme")))
         self.defaultSchemeCombo.setCurrentIndex(
             self.defaultSchemeCombo.findText(
                 Preferences.getHelp("DefaultScheme")))
@@ -104,6 +107,16 @@ class HelpWebBrowserPage(ConfigurationPageBase, Ui_HelpWebBrowserPage):
             idx = 5
         self.expireHistory.setCurrentIndex(idx)
         
+        for language in range(2, QLocale.LastLanguage + 1):
+            if len(QLocale.countriesForLanguage(language)) > 0:
+                self.languageCombo.addItem(QLocale.languageToString(language), language)
+        self.languageCombo.model().sort(0)
+        self.languageCombo.insertSeparator(0)
+        self.languageCombo.insertItem(0, QLocale.languageToString(0), 0)
+        index = self.languageCombo.findData(Preferences.getHelp("SearchLanguage"))
+        if index > -1:
+            self.languageCombo.setCurrentIndex(index)
+        
     def save(self):
         """
         Public slot to save the Help Viewers configuration.
@@ -161,6 +174,14 @@ class HelpWebBrowserPage(ConfigurationPageBase, Ui_HelpWebBrowserPage):
         elif idx == 6:
             historyLimit = -2
         Preferences.setHelp("HistoryLimit", historyLimit)
+        
+        languageIndex = self.languageCombo.currentIndex()
+        if languageIndex > -1:
+            language = self.languageCombo.itemData(languageIndex)
+        else:
+            # fall back to system default
+            language = QLocale.system().language()
+        Preferences.setHelp("SearchLanguage", language)
     
     @pyqtSignature("")
     def on_setCurrentPageButton_clicked(self):
