@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -52,6 +52,7 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             Preferences.getUI("BrowsersHideNonPublic"))
         self.uiBrowsersSortByOccurrenceCheckBox.setChecked(
             Preferences.getUI("BrowsersListContentsByOccurrence"))
+        self.fileFiltersEdit.setText(Preferences.getUI("BrowsersFileFilters"))
         
         self.lvAutoRaiseCheckBox.setChecked(
             Preferences.getUI("LogViewerAutoRaise"))
@@ -110,8 +111,12 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             self.tabsCloseButtonCheckBox.setChecked(
                 Preferences.getUI("SingleCloseButton"))
         
-        self.uiKdeDialogsCheckBox.setChecked(\
-            Preferences.getUI("UseKDEDialogs"))
+        if Utilities.isMacPlatform() or Utilities.isWindowsPlatform():
+            self.uiKdeDialogsCheckBox.setChecked(False)
+            self.dialogsGroupBox.hide()
+        else:
+            self.uiKdeDialogsCheckBox.setChecked(\
+                Preferences.getUI("UseKDEDialogs"))
         
         self.uiColours["LogStdErrColour"] = \
             self.initColour("LogStdErrColour", self.stderrTextColourButton, 
@@ -133,6 +138,9 @@ class InterfacePage(ConfigurationPageBase, Ui_InterfacePage):
             int(self.uiBrowsersHideNonPublicCheckBox.isChecked()))
         Preferences.setUI("BrowsersListContentsByOccurrence", 
             int(self.uiBrowsersSortByOccurrenceCheckBox.isChecked()))
+        Preferences.setUI("BrowsersFileFilters",
+            self.fileFiltersEdit.text())
+        
         Preferences.setUI("LogViewerAutoRaise", 
             int(self.lvAutoRaiseCheckBox.isChecked()))
         Preferences.setUI("CaptionShowsFilename",
