@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -49,9 +49,13 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         self.alternateButton.installEventFilter(self)
         self.primaryClearButton.installEventFilter(self)
         self.alternateClearButton.installEventFilter(self)
+        self.keyEdit.installEventFilter(self)
+        self.alternateKeyEdit.installEventFilter(self)
         
         self.buttonBox.button(QDialogButtonBox.Ok).installEventFilter(self)
         self.buttonBox.button(QDialogButtonBox.Cancel).installEventFilter(self)
+        
+        self.keyEdit.setFocus()
 
     def setKeys(self, key, alternateKey,  noCheck, objectType):
         """
@@ -65,8 +69,8 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         """
         self.keyIndex = 0
         self.keys = [0, 0, 0, 0]
-        self.keyLabel.setText(QString(key))
-        self.alternateKeyLabel.setText(QString(alternateKey))
+        self.keyEdit.setText(QString(key))
+        self.alternateKeyEdit.setText(QString(alternateKey))
         self.primaryButton.setChecked(True)
         self.noCheck = noCheck
         self.objectType = objectType
@@ -77,8 +81,8 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         """
         self.hide()
         self.emit(SIGNAL('shortcutChanged'), 
-                  QKeySequence(self.keyLabel.text()),
-                  QKeySequence(self.alternateKeyLabel.text()), 
+                  QKeySequence(self.keyEdit.text()),
+                  QKeySequence(self.alternateKeyEdit.text()), 
                   self.noCheck, self.objectType)
 
     def __clear(self):
@@ -87,7 +91,7 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         """
         self.keyIndex = 0
         self.keys = [0, 0, 0, 0]
-        self.__setKeyLabelText("")
+        self.__setKeyEditText("")
         
     def __typeChanged(self):
         """
@@ -96,16 +100,16 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         self.keyIndex = 0
         self.keys = [0, 0, 0, 0]
         
-    def __setKeyLabelText(self, txt):
+    def __setKeyEditText(self, txt):
         """
-        Private method to set the text of a key label.
+        Private method to set the text of a key edit.
         
         @param txt text to be set (QString)
         """
         if self.primaryButton.isChecked():
-            self.keyLabel.setText(txt)
+            self.keyEdit.setText(txt)
         else:
-            self.alternateKeyLabel.setText(txt)
+            self.alternateKeyEdit.setText(txt)
         
     def eventFilter(self, watched, event):
         """
@@ -159,12 +163,12 @@ class ShortcutDialog(QDialog, Ui_ShortcutDialog):
         self.keyIndex += 1
         
         if self.keyIndex == 1:
-            self.__setKeyLabelText(QString(QKeySequence(self.keys[0])))
+            self.__setKeyEditText(QString(QKeySequence(self.keys[0])))
         elif self.keyIndex == 2:
-            self.__setKeyLabelText(QString(QKeySequence(self.keys[0], self.keys[1])))
+            self.__setKeyEditText(QString(QKeySequence(self.keys[0], self.keys[1])))
         elif self.keyIndex == 3:
-            self.__setKeyLabelText(QString(QKeySequence(self.keys[0], self.keys[1],
+            self.__setKeyEditText(QString(QKeySequence(self.keys[0], self.keys[1],
                 self.keys[2])))
         elif self.keyIndex == 4:
-            self.__setKeyLabelText(QString(QKeySequence(self.keys[0], self.keys[1],
+            self.__setKeyEditText(QString(QKeySequence(self.keys[0], self.keys[1],
                 self.keys[2], self.keys[3])))
