@@ -171,9 +171,9 @@ class Prefs(object):
                                     # 2 = SOCKS5 proxy
         
         "PluginRepositoryUrl" : \
-            "http://die-offenbachs.homelinux.org/eric/plugins/repository.xml",
+            "http://eric-ide.python-projects.org/plugins4/repository.xml",
         "VersionsUrls" : QtCore.QStringList() \
-            << "http://die-offenbachs.homelinux.org/eric/snapshots4/versions" \
+            << "http://die-offenbachs.homelinux.org:48888/eric/snapshots4/versions" \
             << "http://eric-ide.python-projects.org/snapshots4/versions", 
         
         "OpenOnStartup" : 0,        # 0 = nothing
@@ -564,6 +564,7 @@ class Prefs(object):
         "VcsModified" : QtGui.QColor(QtCore.Qt.yellow),
         "VcsReplaced" : QtGui.QColor(QtCore.Qt.cyan), 
         "VcsUpdate"   : QtGui.QColor(QtCore.Qt.green),
+        "VcsRemoved"  : QtGui.QColor(QtCore.Qt.magenta)
     }
     
     # defaults for the help settings
