@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -21,6 +21,7 @@ from NewDialogClassDialog import NewDialogClassDialog
 from Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
 
 from Utilities import ModuleParser
+import Utilities
 
 import UI.PixmapCache
 
@@ -127,7 +128,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             KQMessageBox.critical(self,
                 self.trUtf8("uic error"),
                 self.trUtf8("""<p>There was an error loading the form <b>%1</b>.</p>"""
-                            """<p>%2</p>""").arg(self.formFile).arg(unicode(err)),
+                            """<p>%2</p>""").arg(self.formFile).arg(str(err)),
                 QMessageBox.StandardButtons(\
                     QMessageBox.Ok))
             return QString()
@@ -145,12 +146,17 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             KQMessageBox.critical(self,
                 self.trUtf8("uic error"),
                 self.trUtf8("""<p>There was an error loading the form <b>%1</b>.</p>"""
-                            """<p>%2</p>""").arg(self.formFile).arg(unicode(err)),
+                            """<p>%2</p>""").arg(self.formFile).arg(str(err)),
                 QMessageBox.StandardButtons(\
                     QMessageBox.Ok))
             return QString()
         
     def __signatures(self):
+        """
+        Private slot to get the signatures.
+        
+        @return list of signatures (list of strings)
+        """
         if self.__module is None:
             return []
             
@@ -168,6 +174,32 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                         signatures.append(meth.name)
         return signatures
         
+    def __mapType(self, type_):
+        """
+        Private method to map a type as reported by Qt's meta object to the
+        correct Python type.
+        
+        @param type_ type as reported by Qt (QByteArray)
+        @return mapped Python type (string)
+        """
+        mapped = unicode(type_)
+        
+        if self.project.getProjectLanguage() == "Python3" or \
+           self.project.getProjectType == "PySide":
+            # 1. check for const
+            mapped = mapped.replace("const ", "")
+            
+            # 2. check fpr *
+            mapped = mapped.replace("*", "")
+            
+            # 3. replace QString and QStringList
+            mapped = mapped.replace("QStringList", "list").replace("QString", "str")
+            
+            # 4. replace double by float
+            mapped = mapped.replace("double", "float")
+        
+        return mapped
+        
     def __updateSlotsModel(self):
         """
         Private slot to update the slots tree display.
@@ -199,9 +231,10 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                         if self.__module is not None:
                             method = "on_%s_%s" % \
                                 (name, metaMethod.signature().split("(")[0])
-                            method2 = "on_%s_%s" % \
-                                (name, 
-                                 QMetaObject.normalizedSignature(metaMethod.signature()))
+                            method2 = "%s(%s)" % \
+                                (method, 
+                                ", ".join([self.__mapType(t)
+                                           for t in metaMethod.parameterTypes()]))
                             
                             if method2 in signatureList or method in signatureList:
                                 itm2.setFlags(Qt.ItemFlags(Qt.ItemIsEnabled))
@@ -210,7 +243,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                                 continue
                         
                         pyqtSignature = \
-                            ", ".join([str(t) for t in metaMethod.parameterTypes()])
+                            ", ".join([self.__mapType(t)
+                                       for t in metaMethod.parameterTypes()])
                         
                         parameterNames = metaMethod.parameterNames()
                         if parameterNames:
@@ -246,7 +280,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             KQMessageBox.critical(self,
                 self.trUtf8("uic error"),
                 self.trUtf8("""<p>There was an error loading the form <b>%1</b>.</p>"""
-                            """<p>%2</p>""").arg(self.formFile).arg(unicode(err)),
+                            """<p>%2</p>""").arg(self.formFile).arg(str(err)),
                 QMessageBox.StandardButtons(\
                     QMessageBox.Ok))
         
@@ -282,7 +316,16 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         if self.__module is None:
             # new file
             try:
-                tmplName = os.path.join(getConfig('ericCodeTemplatesDir'), "impl.py.tmpl")
+                if self.project.getProjectLanguage() == "Python3":
+                    tmplName = os.path.join(getConfig('ericCodeTemplatesDir'),
+                                            "impl_pyqt.py3.tmpl")
+                else:
+                    if self.project.getProjectType() == "PySide":
+                        tmplName = os.path.join(getConfig('ericCodeTemplatesDir'),
+                                                "impl_pyside.py.tmpl")
+                    else:
+                        tmplName = os.path.join(getConfig('ericCodeTemplatesDir'),
+                                                "impl_pyqt.py.tmpl")
                 tmplFile = open(tmplName, 'rb')
                 template = tmplFile.read()
                 tmplFile.close()
@@ -292,7 +335,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     self.trUtf8("""<p>Could not open the code template file "%1".</p>"""
                                 """<p>Reason: %2</p>""")\
                         .arg(tmplName)\
-                        .arg(unicode(why)),
+                        .arg(str(why)),
                     QMessageBox.StandardButtons(\
                         QMessageBox.Ok))
                 return
@@ -317,9 +360,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         else:
             # extend existing file
             try:
-                srcFile = open(self.srcFile, 'rb')
-                sourceImpl = srcFile.readlines()
-                srcFile.close()
+                sourceImpl = Utilities.readEncodedFile(self.srcFile)[0].splitlines(True)
                 if not sourceImpl[-1].endswith(os.linesep):
                     sourceImpl[-1] = "%s%s" % (sourceImpl[-1], os.linesep)
             except IOError, why:
@@ -328,7 +369,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     self.trUtf8("""<p>Could not open the source file "%1".</p>"""
                                 """<p>Reason: %2</p>""")\
                         .arg(self.srcFile)\
-                        .arg(unicode(why)),
+                        .arg(str(why)),
                     QMessageBox.StandardButtons(\
                         QMessageBox.Ok))
                 return
@@ -349,6 +390,13 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                     break
         
         # do the coding stuff
+        if self.project.getProjectLanguage() == "Python3":
+            pyqtSignatureFormat = '@pyqtSlot(%s)'
+        else:
+            if self.project.getProjectType() == "PySide":
+                pyqtSignatureFormat = '@Slot(%s)'
+            else:
+                pyqtSignatureFormat = '@pyqtSignature("%s")'
         for row in range(self.slotsModel.rowCount()):
             topItem = self.slotsModel.item(row)
             for childRow in range(topItem.rowCount()):
@@ -356,8 +404,9 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                 if child.checkState() and \
                    child.flags() & Qt.ItemFlags(Qt.ItemIsUserCheckable):
                     slotsCode.append('%s\n' % indentStr)
-                    slotsCode.append('%s@pyqtSignature("%s")\n' % \
-                        (indentStr, child.data(pyqtSignatureRole).toString()))
+                    slotsCode.append('%s%s\n' % \
+                        (indentStr, 
+                         pyqtSignatureFormat % child.data(pyqtSignatureRole).toString()))
                     slotsCode.append('%sdef %s:\n' % \
                         (indentStr, child.data(pythonSignatureRole).toString()))
                     slotsCode.append('%s"""\n' % (indentStr * 2,))
@@ -375,16 +424,15 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         
         # write the new code
         try:
-            srcFile = open(unicode(self.filenameEdit.text()), 'wb')
-            srcFile.write("".join(sourceImpl))
-            srcFile.close()
+            Utilities.writeEncodedFile(unicode(self.filenameEdit.text()),
+                "".join(sourceImpl), "utf-8")
         except IOError, why:
             KQMessageBox.critical(self,
                 self.trUtf8("Code Generation"),
                 self.trUtf8("""<p>Could not write the source file "%1".</p>"""
                             """<p>Reason: %2</p>""")\
                     .arg(self.filenameEdit.text())\
-                    .arg(unicode(why)),
+                    .arg(str(why)),
                 QMessageBox.StandardButtons(\
                     QMessageBox.Ok))
             return
