@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -309,7 +309,7 @@ class ProjectBaseBrowser(Browser):
         @param fn filename of file to be highlighted (string or QString)
         """
         newfn = os.path.abspath(unicode(fn))
-        newfn = newfn.replace(self.project.ppath + os.sep, '')
+        newfn = self.project.getRelativePath(newfn)
         sindex = self._model.itemIndexByName(newfn)
         if sindex.isValid():
             index = self.model().mapFromSource(sindex)
