@@ -67,6 +67,7 @@ class ProjectBrowser(E4TabWidget):
         self.vcsStatusColorNames = {
             "A" : "VcsAdded",
             "M" : "VcsModified",
+            "O" : "VcsRemoved", 
             "R" : "VcsReplaced", 
             "U" : "VcsUpdate",
             "Z" : "VcsConflict",
@@ -75,6 +76,7 @@ class ProjectBrowser(E4TabWidget):
             " " : self.trUtf8("up to date"), 
             "A" : self.trUtf8("files added"), 
             "M" : self.trUtf8("local modifications"), 
+            "O" : self.trUtf8("files removed"), 
             "R" : self.trUtf8("files replaced"), 
             "U" : self.trUtf8("update required"), 
             "Z" : self.trUtf8("conflict"), 
@@ -384,4 +386,7 @@ class ProjectBrowser(E4TabWidget):
         else:
             self.vcsStatusIndicator.setColor(\
                 Preferences.getProjectBrowserColour(self.vcsStatusColorNames[state]))
-        self.vcsStatusIndicator.setToolTip(self.vcsStatusText[state])
+        if state not in self.vcsStatusText:
+            self.vcsStatusIndicator.setToolTip(self.trUtf8("unknown status"))
+        else:
+            self.vcsStatusIndicator.setToolTip(self.vcsStatusText[state])
