@@ -241,6 +241,7 @@ class ProjectBrowserModel(BrowserModel):
         self.colorNames = {
             "A" : "VcsAdded",
             "M" : "VcsModified",
+            "O" : "VcsRemoved", 
             "R" : "VcsReplaced", 
             "U" : "VcsUpdate",
             "Z" : "VcsConflict",
@@ -249,6 +250,7 @@ class ProjectBrowserModel(BrowserModel):
             " " : QColor(),
             "A" : Preferences.getProjectBrowserColour(self.colorNames["A"]),
             "M" : Preferences.getProjectBrowserColour(self.colorNames["M"]),
+            "O" : Preferences.getProjectBrowserColour(self.colorNames["O"]),
             "R" : Preferences.getProjectBrowserColour(self.colorNames["R"]),
             "U" : Preferences.getProjectBrowserColour(self.colorNames["U"]),
             "Z" : Preferences.getProjectBrowserColour(self.colorNames["Z"]),
@@ -601,7 +603,7 @@ class ProjectBrowserModel(BrowserModel):
             # step 1: check for new entries
             children = itm.children()
             for f in entryInfoList:
-                fpath = unicode(f.absoluteFilePath())
+                fpath = unicode(Utilities.toNativeSeparators(f.absoluteFilePath()))
                 childFound = False
                 for child in children:
                     if child.name() == fpath:
@@ -637,9 +639,10 @@ class ProjectBrowserModel(BrowserModel):
             if len(entryInfoList) != itm.childCount():
                 for row in range(oldCnt - 1, -1, -1):
                     child = itm.child(row)
+                    childname = Utilities.fromNativeSeparators(child.name())
                     entryFound = False
                     for f in entryInfoList:
-                        if unicode(f.absoluteFilePath()) == child.name():
+                        if unicode(f.absoluteFilePath()) == childname:
                             entryFound = True
                             entryInfoList.remove(f)
                             break
