@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -603,7 +603,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             KQMessageBox.critical(self,
                 self.trUtf8("New Form"),
                 self.trUtf8("<p>The new form file <b>%1</b> could not be created.<br>"
-                    "Problem: %2</p>").arg(fname).arg(unicode(e)))
+                    "Problem: %2</p>").arg(fname).arg(str(e)))
             return
         
         self.project.appendFile(fname)
@@ -620,7 +620,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         for itm in itmList:
             fn2 = unicode(itm.fileName())
             fullNames.append(fn2)
-            fn = fn2.replace(self.project.ppath+os.sep, '')
+            fn = self.project.getRelativePath(fn2)
             files.append(fn)
         
         dlg = DeleteFilesConfirmationDialog(self.parent(),
@@ -695,7 +695,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                     KQMessageBox.information(None,
                         self.trUtf8("Form Compilation"),
                         self.trUtf8("<p>The compilation of the form file failed.</p>"
-                            "<p>Reason: %1</p>").arg(unicode(msg)))
+                            "<p>Reason: %1</p>").arg(str(msg)))
         else:
             if not self.noDialog:
                 KQMessageBox.information(None,
@@ -823,7 +823,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         """
         itm = self.model().item(self.currentIndex())
         fn2 = unicode(itm.fileName())
-        fn = fn2.replace(self.project.ppath+os.sep, '')
+        fn = self.project.getRelativePath(fn2)
         self.__compileUI(fn, subclass = True)
         
     def __compileForm(self):
@@ -874,7 +874,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         Private method to compile selected forms to source files.
         """
         items = self.getSelectedItems()
-        files = [unicode(itm.fileName()).replace(self.project.ppath+os.sep, '') \
+        files = [self.project.getRelativePath(unicode(itm.fileName())) \
                  for itm in items]
         
         if self.hooks["compileSelectedForms"] is not None:
