@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -386,7 +386,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         for itm in itmList:
             fn2 = unicode(itm.fileName())
             fullNames.append(fn2)
-            fn = fn2.replace(self.project.ppath+os.sep, '')
+            fn = self.project.getRelativePath(fn2)
             files.append(fn)
         
         dlg = DeleteFilesConfirmationDialog(self.parent(),
@@ -518,7 +518,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         if self.omniidl is not None:
             itm = self.model().item(self.currentIndex())
             fn2 = unicode(itm.fileName())
-            fn = fn2.replace(self.project.ppath+os.sep, '')
+            fn = self.project.getRelativePath(fn2)
             self.__compileIDL(fn)
         
     def __compileAllInterfaces(self):
@@ -556,7 +556,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         if self.omniidl is not None:
             items = self.getSelectedItems()
             
-            files = [unicode(itm.fileName()).replace(self.project.ppath+os.sep, '') \
+            files = [self.project.getRelativePath(unicode(itm.fileName())) \
                      for itm in items]
             numIDLs = len(files)
             progress = KQProgressDialog(self.trUtf8("Compiling interfaces..."), 
