@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -275,13 +275,13 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         for itm in itmList:
             if isinstance(itm, ProjectBrowserFileItem):
                 fn2 = unicode(itm.fileName())
-                fn = fn2.replace(self.project.ppath+os.sep, '')
+                fn = self.project.getRelativePath(fn2)
                 items.append(itm)
                 fullNames.append(fn2)
                 names.append(fn)
             else:
                 dn2 = unicode(itm.dirName())
-                dn = dn2.replace(self.project.ppath+os.sep, '')
+                dn = self.project.getRelativePath(dn2)
                 dirItems.append(itm)
                 dirFullNames.append(dn2)
                 dirNames.append(dn)
@@ -312,11 +312,11 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
         itm = self.model().item(self.currentIndex())
         if isinstance(itm, ProjectBrowserFileItem):
             name = itm.fileName()
+            self.project.repopulateItem(name)
         elif isinstance(itm, ProjectBrowserDirectoryItem):
             name = itm.dirName()
+            self._model.directoryChanged(name)
         else:
             name = ''
         
-        if name:
-            self.project.repopulateItem(name)
         self._resizeColumns(QModelIndex())
