@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -627,7 +627,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if itmList and not previewAll:
             for itm in itmList:
                 if isinstance(itm, ProjectBrowserSimpleDirectoryItem):
-                    dname = unicode(itm.dirName()).replace(self.project.ppath+os.sep, '')
+                    dname = self.project.getRelativePath(unicode(itm.dirName()))
                     trfiles = self.project.pdata["TRANSLATIONS"][:]
                     trfiles.sort()
                     for trfile in trfiles:
@@ -698,7 +698,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         sections.append(("FORMS", forms))
         
         if langs:
-            l = [lang.fileName().replace(self.project.ppath+os.sep, '') \
+            l = [self.project.getRelativePath(lang.fileName()) \
                  for lang in langs if lang.fileName().endswith('.ts')]
         else:
             try:
@@ -885,13 +885,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         else:
             if noobsolete:
                 if self.hooks["generateSelected"] is not None:
-                    l = [lang.fileName().replace(self.project.ppath+os.sep, '') \
+                    l = [self.project.getRelativePath(lang.fileName()) \
                          for lang in langs]
                     self.hooks["generateSelected"](l)
                     return
             else:
                 if self.hooks["generateSelectedWithObsolete"] is not None:
-                    l = [lang.fileName().replace(self.project.ppath+os.sep, '') \
+                    l = [self.project.getRelativePath(lang.fileName()) \
                          for lang in langs]
                     self.hooks["generateSelectedWithObsolete"](l)
                     return
@@ -1027,7 +1027,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 return
         else:
             if self.hooks["releaseSelected"] is not None:
-                l = [lang.fileName().replace(self.project.ppath+os.sep, '') \
+                l = [self.project.getRelativePath(lang.fileName()) \
                      for lang in langs]
                 self.hooks["releaseSelected"](l)
                 return
