@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -112,6 +112,6 @@ class SpellingPropertiesDialog(QDialog, Ui_SpellingPropertiesDialog):
             self.project.pdata["SPELLLANGUAGE"] = \
                 [unicode(self.spellingComboBox.currentText())]
         self.project.pdata["SPELLWORDS"] = \
-            [unicode(self.pwlEdit.text()).replace(self.project.ppath+os.sep, "")]
+            [self.project.getRelativePath(unicode(self.pwlEdit.text()))]
         self.project.pdata["SPELLEXCLUDES"] = \
-            [unicode(self.pelEdit.text()).replace(self.project.ppath+os.sep, "")]
+            [self.project.getRelativePath(unicode(self.pelEdit.text()))]
