@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -52,3 +52,12 @@ class LexerBash(QsciLexerBash, Lexer):
         return style in [QsciLexerBash.DoubleQuotedString, 
                          QsciLexerBash.SingleQuotedString, 
                          QsciLexerBash.SingleQuotedHereDocument]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerBash.keywords(self, kwSet)
