@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -42,3 +42,12 @@ class LexerBatch(QsciLexerBatch, Lexer):
         @return flag indicating a string style (boolean)
         """
         return False
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerBatch.keywords(self, kwSet)
