@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -55,6 +55,15 @@ class LexerCPP(QsciLexerCPP, Lexer):
             self.setDollarsAllowed(Preferences.getEditor("CppDollarsAllowed"))
         except AttributeError:
             pass
+        try:
+            self.setStylePreprocessor(Preferences.getEditor("CppStylePreprocessor"))
+        except AttributeError:
+            pass
+        try:
+            self.setHighlightTripleQuotedStrings(
+                Preferences.getEditor("CppHighlightTripleQuotedStrings"))
+        except AttributeError:
+            pass
     
     def autoCompletionWordSeparators(self):
         """
@@ -85,3 +94,12 @@ class LexerCPP(QsciLexerCPP, Lexer):
                          QsciLexerCPP.SingleQuotedString, 
                          QsciLexerCPP.UnclosedString, 
                          QsciLexerCPP.VerbatimString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerCPP.keywords(self, kwSet)
