@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -44,6 +44,11 @@ class LexerHTML(QsciLexerHTML, Lexer):
             self.setFoldScriptHeredocs(Preferences.getEditor("HtmlFoldScriptHeredocs"))
         except AttributeError:
             pass
+        try:
+            self.setDjangoTemplates(Preferences.getEditor("HtmlDjangoTemplates"))
+            self.setMakoTemplates(Preferences.getEditor("HtmlMakoTemplates"))
+        except AttributeError:
+            pass
     
     def isCommentStyle(self, style):
         """
@@ -97,3 +102,12 @@ class LexerHTML(QsciLexerHTML, Lexer):
                          QsciLexerHTML.ASPPythonTripleSingleQuotedString, 
                          QsciLexerHTML.PHPDoubleQuotedString, 
                          QsciLexerHTML.PHPSingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerHTML.keywords(self, kwSet)
