@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -62,3 +62,12 @@ class LexerPOV(QsciLexerPOV, Lexer):
         """
         return style in [QsciLexerPOV.String, 
                          QsciLexerPOV.UnclosedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerPOV.keywords(self, kwSet)
