@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -74,3 +74,12 @@ class LexerPascal(QsciLexerPascal, Lexer):
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerPascal.SingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerPascal.keywords(self, kwSet)
