@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -39,6 +39,10 @@ class LexerPerl(QsciLexerPerl, Lexer):
             self.setFoldPODBlocks(Preferences.getEditor("PerlFoldPODBlocks"))
         except AttributeError:
             pass
+        try:
+            self.setFoldAtElse(Preferences.getEditor("PerlFoldAtElse"))
+        except AttributeError:
+            pass
     
     def autoCompletionWordSeparators(self):
         """
@@ -71,3 +75,12 @@ class LexerPerl(QsciLexerPerl, Lexer):
                          QsciLexerPerl.QuotedStringQX, 
                          QsciLexerPerl.SingleQuotedHereDocument, 
                          QsciLexerPerl.SingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerPerl.keywords(self, kwSet)
