@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,6 +33,10 @@ class LexerProperties(QsciLexerProperties, Lexer):
         Public slot to initialize the properties.
         """
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
+        try:
+            self.setInitialSpaces(Preferences.getEditor("PropertiesInitialSpaces"))
+        except AttributeError:
+            pass
     
     def isCommentStyle(self, style):
         """
@@ -49,3 +53,12 @@ class LexerProperties(QsciLexerProperties, Lexer):
         @return flag indicating a string style (boolean)
         """
         return False
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerProperties.keywords(self, kwSet)
