@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -48,6 +48,17 @@ class LexerPython(QsciLexerPython, Lexer):
             self.setV3BytesAllowed(Preferences.getEditor("PythonAllowV3Bytes"))
         except AttributeError:
             pass
+        try:
+            self.setFoldQuotes(Preferences.getEditor("PythonFoldQuotes"))
+            self.setStringsOverNewlineAllowed(
+                Preferences.getEditor("PythonStringsOverNewLineAllowed"))
+        except AttributeError:
+            pass
+        try:
+            self.setHighlightSubidentifiers(
+                Preferences.getEditor("PythonHighlightSubidentifier"))
+        except AttributeError:
+            pass
         
     def getIndentationDifference(self, line, editor):
         """
@@ -117,3 +128,12 @@ class LexerPython(QsciLexerPython, Lexer):
                          QsciLexerPython.TripleDoubleQuotedString, 
                          QsciLexerPython.TripleSingleQuotedString, 
                          QsciLexerPython.UnclosedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerPython.keywords(self, kwSet)
