@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,10 +11,11 @@ from PyQt4.Qsci import QsciLexerRuby
 from PyQt4.QtCore import QString, QStringList
 
 from Lexer import Lexer
+import Preferences
 
 class LexerRuby(QsciLexerRuby, Lexer):
     """ 
-    Subclass to implement some additional lexer dependant methods.
+    Subclass to implement some additional lexer dependent methods.
     """
     def __init__(self, parent=None):
         """
@@ -27,6 +28,16 @@ class LexerRuby(QsciLexerRuby, Lexer):
         
         self.commentString = QString("#")
     
+    def initProperties(self):
+        """
+        Public slot to initialize the properties.
+        """
+        try:
+            self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
+            self.setFoldComments(Preferences.getEditor("RubyFoldComment"))
+        except AttributeError:
+            pass
+    
     def autoCompletionWordSeparators(self):
         """
         Public method to return the list of separators for autocompletion.
@@ -57,3 +68,12 @@ class LexerRuby(QsciLexerRuby, Lexer):
                          QsciLexerRuby.PercentStringw, 
                          QsciLexerRuby.PercentStringx, 
                          QsciLexerRuby.SingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerRuby.keywords(self, kwSet)
