@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,6 +33,14 @@ class LexerSQL(QsciLexerSQL, Lexer):
         self.setFoldComments(Preferences.getEditor("SqlFoldComment"))
         self.setBackslashEscapes(Preferences.getEditor("SqlBackslashEscapes"))
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
+        try:
+            self.setDottedWords(Preferences.getEditor("SqlDottedWords"))
+            self.setFoldAtElse(Preferences.getEditor("SqlFoldAtElse"))
+            self.setFoldOnlyBegin(Preferences.getEditor("SqlFoldOnlyBegin"))
+            self.setHashComments(Preferences.getEditor("SqlHashComments"))
+            self.setQuotedIdentifiers(Preferences.getEditor("SqlQuotedIdentifiers"))
+        except AttributeError:
+            pass
     
     def isCommentStyle(self, style):
         """
@@ -53,3 +61,12 @@ class LexerSQL(QsciLexerSQL, Lexer):
         """
         return style in [QsciLexerSQL.DoubleQuotedString, 
                          QsciLexerSQL.SingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerSQL.keywords(self, kwSet)
