@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,6 +37,10 @@ class LexerTCL(QsciLexerTCL, Lexer):
             self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
         except AttributeError:
             pass
+        try:
+            self.setFoldComments(Preferences.getEditor("TclFoldComment"))
+        except AttributeError:
+            pass
     
     def isCommentStyle(self, style):
         """
@@ -56,3 +60,12 @@ class LexerTCL(QsciLexerTCL, Lexer):
         @return flag indicating a string style (boolean)
         """
         return style in [QsciLexerTCL.QuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerTCL.keywords(self, kwSet)
