@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -98,3 +98,12 @@ class LexerXML(QsciLexerXML, Lexer):
                          QsciLexerXML.ASPPythonTripleSingleQuotedString, 
                          QsciLexerXML.PHPDoubleQuotedString, 
                          QsciLexerXML.PHPSingleQuotedString]
+    
+    def defaultKeywords(self, kwSet):
+        """
+        Public method to get the default keywords.
+        
+        @param kwSet number of the keyword set (integer)
+        @return string giving the keywords (string) or None
+        """
+        return QsciLexerXML.keywords(self, kwSet)
