@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -70,7 +70,7 @@ expression, special characters interpreted are:</p>
 <tr><td><code>.</code></td><td>Matches any character</td></tr>
 <tr><td><code>\(</code></td><td>This marks the start of a region for tagging a match.</td></tr>
 <tr><td><code>\)</code></td><td>This marks the end of a tagged region.</td></tr>
-<tr><td><code>\n</code></td>
+<tr><td><code>\\n</code></td>
 <td>Where <code>n</code> is 1 through 9 refers to the first through ninth tagged region
 when replacing. For example, if the search string was <code>Fred\([1-9]\)XXX</code> and
 the replace string was <code>Sam\1YYY</code>, when applied to <code>Fred2XXX</code> this
@@ -79,9 +79,9 @@ would generate <code>Sam2YYY</code>.</td></tr>
 <td>This matches the start of a word using Scintilla's definitions of words.</td></tr>
 <tr><td><code>\&gt;</code></td>
 <td>This matches the end of a word using Scintilla's definition of words.</td></tr>
-<tr><td><code>\x</code></td>
+<tr><td><code>\\x</code></td>
 <td>This allows you to use a character x that would otherwise have a special meaning. For
-example, \[ would be interpreted as [ and not as the start of a character set.</td></tr>
+example, \\[ would be interpreted as [ and not as the start of a character set.</td></tr>
 <tr><td><code>[...]</code></td>
 <td>This indicates a set of characters, for example, [abc] means any of the characters a,
 b or c. You can also use ranges, for example [a-z] for any lower case character.</td></tr>
@@ -107,8 +107,12 @@ character except an alphabetic character.</td></tr>
         self.ui.findNextButton.setIcon(UI.PixmapCache.getIcon("1rightarrow.png"))
         
         if replace:
-            self.ui.replaceButton.setIcon(UI.PixmapCache.getIcon("editReplace.png"))
-            self.ui.replaceAllButton.setIcon(UI.PixmapCache.getIcon("editReplaceAll.png"))
+            self.ui.replaceButton.setIcon(
+                UI.PixmapCache.getIcon("editReplace.png"))
+            self.ui.replaceSearchButton.setIcon(
+                UI.PixmapCache.getIcon("editReplaceSearch.png"))
+            self.ui.replaceAllButton.setIcon(
+                UI.PixmapCache.getIcon("editReplaceAll.png"))
         
         self.connect(self.ui.findtextCombo.lineEdit(), SIGNAL("returnPressed()"), 
                      self.__findByReturnPressed)
@@ -131,12 +135,14 @@ character except an alphabetic character.</td></tr>
             self.ui.findPrevButton.setEnabled(False)
             if self.replace:
                 self.ui.replaceButton.setEnabled(False)
+                self.ui.replaceSearchButton.setEnabled(False)
                 self.ui.replaceAllButton.setEnabled(False)
         else:
             self.ui.findNextButton.setEnabled(True)
             self.ui.findPrevButton.setEnabled(True)
             if self.replace:
                 self.ui.replaceButton.setEnabled(False)
+                self.ui.replaceSearchButton.setEnabled(False)
                 self.ui.replaceAllButton.setEnabled(True)
 
     @pyqtSignature("")
@@ -169,6 +175,7 @@ character except an alphabetic character.</td></tr>
         if ok:
             if self.replace:
                 self.ui.replaceButton.setEnabled(True)
+                self.ui.replaceSearchButton.setEnabled(True)
         else:
             KQMessageBox.information(self, self.windowTitle(),
                 self.trUtf8("'%1' was not found.").arg(txt))
@@ -203,6 +210,7 @@ character except an alphabetic character.</td></tr>
         if ok:
             if self.replace:
                 self.ui.replaceButton.setEnabled(True)
+                self.ui.replaceSearchButton.setEnabled(True)
         else:
             KQMessageBox.information(self, self.windowTitle(),
                 self.trUtf8("'%1' was not found.").arg(txt))
@@ -271,8 +279,13 @@ character except an alphabetic character.</td></tr>
                 line = self.__selection[2]
                 index = self.__selection[3]
             else:
-                line = lineFrom
-                index = indexFrom - 1
+                if (lineFrom, indexFrom) == (-1, -1):
+                    # no selection present
+                    line = cline
+                    index = cindex
+                else:
+                    line = lineFrom
+                    index = indexFrom - 1
             if self.ui.selectionCheckBox.isChecked() and \
                line == self.__selection[0] and \
                index >= 0 and \
@@ -377,6 +390,7 @@ character except an alphabetic character.</td></tr>
         self.ui.findtextCombo.setEditText(text)
         self.ui.findtextCombo.lineEdit().selectAll()
         self.ui.findtextCombo.setFocus()
+        self.on_findtextCombo_editTextChanged(text)
         
         self.ui.caseCheckBox.setChecked(False)
         self.ui.wordCheckBox.setChecked(False)
@@ -420,10 +434,26 @@ character except an alphabetic character.</td></tr>
         """
         Private slot to replace one occurrence of text.
         """
+        self.__doReplace(False)
+    
+    @pyqtSignature("")
+    def on_replaceSearchButton_clicked(self):
+        """
+        Private slot to replace one occurrence of text and search for the next one.
+        """
+        self.__doReplace(True)
+    
+    def __doReplace(self, searchNext):
+        """
+        Private method to replace one occurrence of text.
+        
+        @param searchNext flag indicating to search for the next occurrence (boolean).
+        """
         self.__finding = True
         
         # Check enabled status due to dual purpose usage of this method
-        if not self.ui.replaceButton.isEnabled():
+        if not self.ui.replaceButton.isEnabled() and \
+           not self.ui.replaceSearchButton.isEnabled():
             return
         
         ftxt = self.ui.findtextCombo.currentText()
@@ -438,15 +468,20 @@ character except an alphabetic character.</td></tr>
         
         aw = self.viewmanager.activeWindow()
         aw.replace(rtxt)
-        ok = self.__findNextPrev(ftxt, self.__findBackwards)
         
-        if not ok:
+        if searchNext:
+            ok = self.__findNextPrev(ftxt, self.__findBackwards)
+            if not ok:
+                self.ui.replaceButton.setEnabled(False)
+                self.ui.replaceSearchButton.setEnabled(False)
+                KQMessageBox.information(self, self.windowTitle(),
+                    self.trUtf8("'%1' was not found.").arg(ftxt))
+        else:
             self.ui.replaceButton.setEnabled(False)
-            KQMessageBox.information(self, self.windowTitle(),
-                self.trUtf8("'%1' was not found.").arg(ftxt))
+            self.ui.replaceSearchButton.setEnabled(False)
         
         self.__finding = False
-        
+    
     @pyqtSignature("")
     def on_replaceAllButton_clicked(self):
         """
@@ -510,6 +545,7 @@ character except an alphabetic character.</td></tr>
         if wordWrap:
             self.ui.wrapCheckBox.setChecked(True)
         self.ui.replaceButton.setEnabled(False)
+        self.ui.replaceSearchButton.setEnabled(False)
         
         if found:
             KQMessageBox.information(self, self.windowTitle(),
@@ -538,6 +574,7 @@ character except an alphabetic character.</td></tr>
         self.ui.findtextCombo.setEditText(text)
         self.ui.findtextCombo.lineEdit().selectAll()
         self.ui.findtextCombo.setFocus()
+        self.on_findtextCombo_editTextChanged(text)
         
         self.ui.replacetextCombo.clear()
         self.ui.replacetextCombo.addItems(self.replaceHistory)
