@@ -215,7 +215,7 @@ class Terminal(QsciScintillaCompat):
         @param data data to be sent to the shell process (string or QString)
         """
         pdata = QByteArray()
-        pdata.append(data)
+        pdata.append(QString(data).toUtf8())
         self.__process.write(pdata)
         
     def __sendCtrl(self, cmd):
@@ -436,7 +436,7 @@ class Terminal(QsciScintillaCompat):
         @return tuple of two values (int, int) giving the line and column
         """
         line = self.lines() - 1
-        return (line, self.lineLength(line))
+        return (line, self.text(line).length())
         
     def __write(self, s):
         """
@@ -600,7 +600,7 @@ class Terminal(QsciScintillaCompat):
             self.setCursorPosition(line, col)
             self.setSelection(*(self.__lastPos + self.getCursorPosition()))
             buf = unicode(self.selectedText())
-            self.setCursorPosition(line, col)   # select nothin
+            self.setCursorPosition(line, col)   # select nothing
             self.insert('\n')
             self.__executeCommand(buf)
         
