@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -673,13 +673,23 @@ class TemplateViewer(QTreeWidget):
             editor.endUndoAction()
             editor.setFocus()
 
-    def applyNamedTemplate(self, templateName):
+    def applyNamedTemplate(self, templateName, groupName=""):
         """
         Public method to apply a template given a template name.
         
         @param templateName name of the template item to apply (string or QString)
+        @param groupName name of the group to get the entry from (string or QString).
+            Empty means to apply the first template found with the given name.
         """
-        for group in self.groups.values():
+        groupName = unicode(groupName)
+        if groupName:
+            if self.hasGroup(groupName):
+                groups = [self.groups[groupName]]
+            else:
+                return
+        else:
+            groups = self.groups.values()
+        for group in groups:
             template = group.getEntry(templateName)
             if template is not None:
                 self.applyTemplate(template)
@@ -698,7 +708,16 @@ class TemplateViewer(QTreeWidget):
         self.groups[unicode(groupName)].addEntry(unicode(name), unicode(description), 
                                                  unicode(template), quiet = quiet)
         self.__resort()
+    
+    def hasGroup(self, name):
+        """
+        Public method to check, if a group with the given name exists.
         
+        @param name name of the group to be checked for (string or QString)
+        @return flag indicating an existing group (boolean)
+        """
+        return unicode(name) in self.groups
+    
     def addGroup(self, name, language = "All"):
         """
         Public method to add a group.
@@ -893,27 +912,47 @@ class TemplateViewer(QTreeWidget):
         """
         e4App().getObject("UserInterface").showPreferences("templatesPage")
     
-    def hasTemplate(self, entryName):
+    def hasTemplate(self, entryName, groupName=""):
         """
         Public method to check, if an entry of the given name exists.
         
         @param entryName name of the entry to check for (string or QString)
+        @param groupName name of the group to check the entry (string or QString).
+            Empty means to check all groups.
         @return flag indicating the existence (boolean)
         """
-        for group in self.groups.values():
+        groupName = unicode(groupName)
+        if groupName:
+            if self.hasGroup(groupName):
+                groups = [self.groups[groupName]]
+            else:
+                groups = []
+        else:
+            groups = self.groups.values()
+        for group in groups:
             if group.hasEntry(entryName):
                 return True
         
         return False
     
-    def getTemplateNames(self, start):
+    def getTemplateNames(self, start, groupName=""):
         """
         Public method to get the names of templates starting with the given string.
         
         @param start start string of the name (string or QString)
+        @param groupName name of the group to get the entry from (string or QString).
+            Empty means to look in all groups.
         @return sorted list of matching template names (list of strings)
         """
         names = []
-        for group in self.groups.values():
+        groupName = unicode(groupName)
+        if groupName:
+            if self.hasGroup(groupName):
+                groups = [self.groups[groupName]]
+            else:
+                groups = []
+        else:
+            groups = self.groups.values()
+        for group in groups:
             names.extend(group.getEntryNames(start))
         return sorted(names)
