@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,7 +17,7 @@ from Utilities.SingleApplication import SingleApplicationClient, SingleApplicati
 # define some module global stuff
 ###########################################################################
 
-SAFile = "eric4-trpreviewer.lck"
+SAFile = "eric4_trpreviewer.lck"
 
 # define the protocol tokens
 SALoadForm =        '>LoadForm<'
