@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -136,7 +136,6 @@ class Browser(QTreeView):
         """
         Public slot to perform a layout operation.
         """
-        self.doItemsLayout()
         self._resizeColumns(QModelIndex())
         self._resort()
         
@@ -207,6 +206,10 @@ class Browser(QTreeView):
             QApplication.translate('Browser', 'Remove from toplevel'),
             self.__removeToplevel)
         self.dirMenu.addSeparator()
+        self.dirMenu.addAction(QApplication.translate('Browser', 
+            'Refresh directory'),
+            self.__refreshDirectory)
+        self.dirMenu.addSeparator()
         self.dirMenu.addAction(QApplication.translate('Browser', 
             'Find in this directory'),
             self.__findInDirectory)
@@ -312,13 +315,13 @@ class Browser(QTreeView):
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
                 if itm.isPythonFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "Python")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python")
                 elif itm.isPython3File():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "Python3")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Python3")
                 elif itm.isRubyFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "Ruby")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "Ruby")
                 elif itm.isDFile():
-                    self.emit(SIGNAL('sourceFile'), itm.fileName(), 1, "D")
+                    self.emit(SIGNAL('sourceFile'), itm.fileName(), -1, "D")
                 elif itm.isDesignerFile():
                     self.emit(SIGNAL('designerFile'), itm.fileName())
                 elif itm.isDesignerHeaderFile():
@@ -427,6 +430,14 @@ class Browser(QTreeView):
         dname = self.model().item(index).dirName()
         self.__model.addTopLevelDir(dname)
         
+    def __refreshDirectory(self):
+        """
+        Private slot to refresh a directory entry.
+        """
+        index = self.currentIndex()
+        refreshDir = self.model().item(index).dirName()
+        self.__model.directoryChanged(refreshDir)
+        
     def __findInDirectory(self):
         """
         Private slot to handle the Find in directory popup menu entry.
