@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -315,7 +315,7 @@ class DiffDialog(QWidget, Ui_DiffDialog):
             KQMessageBox.critical(self, self.trUtf8('Save Diff'),
                 self.trUtf8('<p>The patch file <b>%1</b> could not be saved.<br />'
                             'Reason: %2</p>')
-                    .arg(unicode(fname)).arg(unicode(why)))
+                    .arg(unicode(fname)).arg(str(why)))
 
     @pyqtSignature("")
     def on_diffButton_clicked(self):
@@ -517,4 +517,4 @@ class DiffWindow(KQMainWindow):
             QApplication.exit()
             return True
         
-        return False
\ No newline at end of file
+        return False
