@@ -141,8 +141,10 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 # item is not user checkable if setFirstColumnSpanned is True (< 4.5.0)
             self.__lastFileItem.setData(0, self.md5Role, QVariant(md5))
         
-        itm = QTreeWidgetItem(self.__lastFileItem, [' %5d ' % line, text])
+        itm = QTreeWidgetItem(self.__lastFileItem)
         itm.setTextAlignment(0,  Qt.AlignRight)
+        itm.setData(0, Qt.DisplayRole, line)
+        itm.setData(1, Qt.DisplayRole, text)
         itm.setData(0, self.lineRole, QVariant(line))
         itm.setData(0, self.startRole, QVariant(start))
         itm.setData(0, self.endRole, QVariant(end))
