@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -33,14 +33,14 @@ def __showwarning(message, category, filename, lineno, file = None, line = ""):
         err.filename = filename
         err.lineno = lineno
         raise err
-
+    
 import warnings
 warnings.showwarning = __showwarning
 
 from codecs import BOM_UTF8, BOM_UTF16, BOM_UTF32
 
-from PyQt4.QtCore import QRegExp, QString, QStringList, QDir, QProcess, Qt, \
-    qVersion, PYQT_VERSION_STR
+from PyQt4.QtCore import QRegExp, QString, QStringList, QDir, QProcess, Qt, QByteArray, \
+    qVersion, PYQT_VERSION_STR, QCryptographicHash
 from PyQt4.QtGui import QApplication
 from PyQt4.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
 
@@ -133,6 +133,16 @@ def readEncodedFile(filename):
     f.close()
     return decode(text)
 
+def decodeWithHash(text):
+    """
+    Function to decode a text and calculate the MD5 hash.
+    
+    @param text text to decode (string)
+    @return decoded text, encoding and MD5 hash
+    """
+    hash = str(QCryptographicHash.hash(QByteArray(text), QCryptographicHash.Md5).toHex())
+    return decode(text) + (hash, )
+    
 def decode(text):
     """
     Function to decode a text.
@@ -195,6 +205,47 @@ def decode(text):
     # Assume Latin-1 (behaviour before 3.7.1)
     return unicode(text, "latin-1"), 'latin-1-guessed'
 
+def decodeBytes(buffer):
+    """
+    Function to decode some text into a unicode string.
+    
+    @param buffer string buffer to decode (string)
+    @return decoded text (unicode)
+    """
+    # try UTF with BOM
+    try:
+        if buffer.startswith(BOM_UTF8):
+            # UTF-8 with BOM
+            return unicode(buffer[len(BOM_UTF8):], 'utf-8')
+        elif buffer.startswith(BOM_UTF16):
+            # UTF-16 with BOM
+            return unicode(buffer[len(BOM_UTF16):], 'utf-16')
+        elif buffer.startswith(BOM_UTF32):
+            # UTF-32 with BOM
+            return unicode(buffer[len(BOM_UTF32):], 'utf-32')
+    except (UnicodeError, LookupError):
+        pass
+    
+    # try UTF-8
+    try:
+        return unicode(buffer, "utf-8")
+    except UnicodeError:
+        pass
+    
+    # try codec detection
+    try:
+        import ThirdParty.CharDet.chardet
+        guess = ThirdParty.CharDet.chardet.detect(buffer)
+        if guess and guess['encoding'] is not None:
+            codec = guess['encoding'].lower()
+            return unicode(buffer, codec)
+    except (UnicodeError, LookupError):
+        pass
+    except ImportError:
+        pass
+    
+    return unicode(buffer, "utf-8", "ignore")
+
 def writeEncodedFile(filename, text, orig_coding):
     """
     Function to write a file with properly encoded text.
@@ -220,6 +271,8 @@ def encode(text, orig_coding):
     @param orig_coding type of the original coding (string)
     @return encoded text and encoding
     """
+    orig_coding = str(orig_coding)
+    
     if orig_coding == 'utf-8-bom':
         return BOM_UTF8 + text.encode("utf-8"), 'utf-8-bom'
     
@@ -941,9 +994,9 @@ def compile(file, codestring = ""):
     @param file source filename (string)
     @param codestring string containing the code to compile (string)
     @return A tuple indicating status (1 = an error was found), the
-        filename, the linenumber, the code string and the error message
-        (boolean, string, string, string, string). The values are only
-        valid, if the status equals 1.
+        filename, the linenumber, the index number, the code string and 
+        the error message (boolean, string, string, string, string, string).
+        The values are only valid, if the status equals 1.
     """
     import __builtin__
     if not codestring:
@@ -952,7 +1005,7 @@ def compile(file, codestring = ""):
             codestring, encoding = decode(f.read())
             f.close()
         except IOError:
-            return (0, None, None, None, None)
+            return (0, None, None, None, None, None)
 
     if type(codestring) == type(u""):
         codestring = codestring.encode('utf-8')
@@ -970,7 +1023,7 @@ def compile(file, codestring = ""):
             try:
                 import quixote.ptl_compile
             except ImportError:
-                return (0, None, None, None, None)
+                return (0, None, None, None, None, None)
             template = quixote.ptl_compile.Template(codestring, file)
             template.compile()
             codeobject = template.code
@@ -978,48 +1031,53 @@ def compile(file, codestring = ""):
             codeobject = __builtin__.compile(codestring, file, 'exec')
     except SyntaxError, detail:
         import traceback, re
+        index = "0"
+        code = ""
+        error = ""
         lines = traceback.format_exception_only(SyntaxError, detail)
         match = re.match('\s*File "(.+)", line (\d+)', 
             lines[0].replace('<string>', '%s' % file))
         if match is not None:
             fn, line = match.group(1, 2)
             if lines[1].startswith('SyntaxError:'):
-                code = ""
                 error = re.match('SyntaxError: (.+)', lines[1]).group(1)
             else:
                 code = re.match('(.+)', lines[1]).group(1)
-                error = ""
                 for seLine in lines[2:]:
                     if seLine.startswith('SyntaxError:'):
                         error = re.match('SyntaxError: (.+)', seLine).group(1)
+                    elif seLine.rstrip().endswith('^'):
+                        index = len(seLine.rstrip()) - 4
         else:
             fn = detail.filename
             line = detail.lineno and detail.lineno or 1
-            code = ""
+            index = detail.offset and detail.offset or 1
             error = detail.msg
-        return (1, fn, line, code, error)
+        return (1, fn, line, index, code, error)
     except ValueError, detail:
+        index = "0"
+        code = ""
         try:
             fn = detail.filename
             line = detail.lineno
             error = detail.msg
         except AttributeError:
             fn = file
-            line = 1
+            line = "1"
             error = unicode(detail)
-        code = ""
-        return (1, fn, line, code, error)
+        return (1, fn, line, index, code, error)
     except StandardError, detail:
         try:
             fn = detail.filename
             line = detail.lineno
+            index = "0"
             code = ""
             error = detail.msg
-            return (1, fn, line, code, error)
+            return (1, fn, line, index, code, error)
         except:         # this catchall is intentional
             pass
     
-    return (0, None, None, None, None)
+    return (0, None, None, None, None, None)
 
 def getConfigDir():
     """
@@ -1106,6 +1164,26 @@ def generateQtToolName(toolname):
                        Preferences.getQt("QtToolsPostfix4")
                       )
 
+def getQtMacBundle(toolname):
+    """
+    Module function to determine the correct Mac OS X bundle name for Qt tools.
+    
+    @param toolname  plain name of the tool (e.g. "designer") (string or QString)
+    @return bundle name of the Qt tool (string)
+    """
+    toolname = unicode(toolname)
+    qtDir = Preferences.getQt("Qt4Dir")
+    bundles = [
+        os.path.join(qtDir, 'bin', generateQtToolName(toolname.capitalize())) + ".app",
+        os.path.join(qtDir, 'bin', generateQtToolName(toolname)) + ".app",
+        os.path.join(qtDir, generateQtToolName(toolname.capitalize())) + ".app",
+        os.path.join(qtDir, generateQtToolName(toolname)) + ".app",
+    ]
+    for bundle in bundles:
+        if os.path.exists(bundle):
+            return bundle
+    return ""
+
 def prepareQtMacBundle(toolname, version, args):
     """
     Module function for starting Qt tools that are Mac OS X bundles.
@@ -1115,21 +1193,19 @@ def prepareQtMacBundle(toolname, version, args):
     @param args    name of input file for tool, if any (QStringList)
     @return command-name and args for QProcess (tuple)
     """
-    if version == 4:
-        qtDir = Preferences.getQt("Qt4Dir")
-    else:
+    if version != 4:
         return ("", QStringList())
     
-    fullBundle = os.path.join(qtDir, 'bin',
-        generateQtToolName(toolname)) + ".app"
-    if not os.path.exists(fullBundle):
-        fullBundle = os.path.join(qtDir, 
-            generateQtToolName(toolname)) + ".app"
+    fullBundle = getQtMacBundle(toolname)
+    if fullBundle == "":
+        return ("", QStringList())
 
     newArgs = QStringList()
     newArgs.append("-a")
     newArgs.append(fullBundle)
-    newArgs += args
+    if not args.isEmpty():
+        newArgs.append("--args")
+        newArgs += args
 
     return ("open", newArgs)
 
