@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -268,8 +268,7 @@ class VcsProjectBrowserHelper(QObject):
                 names = [unicode(itm.dirName()) for itm in items]
             else:
                 names = [unicode(itm.fileName()) for itm in items]
-            files = [\
-                name.replace(self.browser.project.ppath+os.sep, '') \
+            files = [self.browser.project.getRelativePath(name) \
                 for name in names]
             
             dlg = DeleteFilesConfirmationDialog(self.parent(),
