@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -326,43 +326,45 @@ class VcsProjectHelper(QObject):
             0, False)
         if not ok:
             return
+        vcsSystem = None
         for vcsSystem, vcsSystemDisplay in vcsSystemsDict.items():
             if vcsSystemDisplay == vcsSelected:
                 break
         
-        self.project.pdata["VCS"] = [vcsSystem]
-        self.project.vcs = self.project.initVCS(vcsSystem)
-        if self.project.vcs is not None:
-            vcsdlg = self.project.vcs.vcsOptionsDialog(self.project, self.project.name, 1)
-            if vcsdlg.exec_() == QDialog.Accepted:
-                vcsDataDict = vcsdlg.getData()
-                # edit VCS command options
-                vcores = KQMessageBox.question(None,
-                    self.trUtf8("Import Project"),
-                    self.trUtf8("""Would you like to edit the VCS command options?"""),
-                    QMessageBox.StandardButtons(\
-                        QMessageBox.No | \
-                        QMessageBox.Yes),
-                    QMessageBox.No)
-                if vcores == QMessageBox.Yes:
-                    codlg = vcsCommandOptionsDialog(self.project.vcs)
-                    if codlg.exec_() == QDialog.Accepted:
-                        self.project.vcs.vcsSetOptions(codlg.getOptions())
-                self.project.setDirty(True)
-                self.project.vcs.vcsSetDataFromDict(vcsDataDict)
-                self.project.saveProject()
-                isVcsControlled = \
-                    self.project.vcs.vcsImport(vcsDataDict, self.project.ppath)[0]
-                if isVcsControlled:
-                    # reopen the project
-                    self.project.openProject(self.project.pfile)
+        if vcsSystem:
+            self.project.pdata["VCS"] = [vcsSystem]
+            self.project.vcs = self.project.initVCS(vcsSystem)
+            if self.project.vcs is not None:
+                vcsdlg = self.project.vcs.vcsOptionsDialog(self.project, self.project.name, 1)
+                if vcsdlg.exec_() == QDialog.Accepted:
+                    vcsDataDict = vcsdlg.getData()
+                    # edit VCS command options
+                    vcores = KQMessageBox.question(None,
+                        self.trUtf8("Import Project"),
+                        self.trUtf8("""Would you like to edit the VCS command options?"""),
+                        QMessageBox.StandardButtons(\
+                            QMessageBox.No | \
+                            QMessageBox.Yes),
+                        QMessageBox.No)
+                    if vcores == QMessageBox.Yes:
+                        codlg = vcsCommandOptionsDialog(self.project.vcs)
+                        if codlg.exec_() == QDialog.Accepted:
+                            self.project.vcs.vcsSetOptions(codlg.getOptions())
+                    self.project.setDirty(True)
+                    self.project.vcs.vcsSetDataFromDict(vcsDataDict)
+                    self.project.saveProject()
+                    isVcsControlled = \
+                        self.project.vcs.vcsImport(vcsDataDict, self.project.ppath)[0]
+                    if isVcsControlled:
+                        # reopen the project
+                        self.project.openProject(self.project.pfile)
+                    else:
+                        # revert the changes to the local project 
+                        # because the project dir is not a VCS directory
+                        revertChanges()
                 else:
-                    # revert the changes to the local project 
-                    # because the project dir is not a VCS directory
+                    # revert the changes because user cancelled
                     revertChanges()
-            else:
-                # revert the changes because user cancelled
-                revertChanges()
 
     def _vcsUpdate(self):
         """
