@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2011 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002-2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric4.
 
@@ -21,6 +21,7 @@ import distutils.sysconfig
 
 # Define the globals.
 progName = None
+currDir = os.getcwd()
 modDir = None
 pyModDir = None
 platBinDir = None
@@ -30,14 +31,29 @@ doCleanup = True
 doCompile = True
 cfg = {}
 progLanguages = ["Python", "Ruby"]
+sourceDir = "eric"
+configName = 'eric4config.py'
 
 # Define blacklisted versions of the prerequisites
 BlackLists = {
-    "sip"         : ["4.11"], 
+    "sip"         : ["4.11", "4.12.3"], 
     "PyQt4"       : ["4.7.5"], 
     "QScintilla2" : [], 
 }
 
+def exit(rcode=0):
+    """
+    Exit the install script.
+    """
+    global currDir
+    
+    if sys.platform.startswith("win"):
+        raw_input("Press enter to continue...")
+    
+    os.chdir(currDir)
+    
+    sys.exit(rcode)
+
 def usage(rcode = 2):
     """
     Display a usage message and exit.
@@ -76,7 +92,7 @@ def usage(rcode = 2):
     print "These define the directories for the installation of the various parts of"\
           " eric4."
 
-    sys.exit(rcode)
+    exit(rcode)
 
 
 def initGlobals():
@@ -118,7 +134,7 @@ def copyToFile(name, text):
     @param name the name of the file.
     @param text the contents to copy to the file.
     """
-    f = open(name,"w")
+    f = open(name, "w")
     f.write(text)
     f.close()
 
@@ -139,21 +155,32 @@ def wrapperName(dname, wfile):
     return wname
 
 
-def createPyWrapper(pydir, wfile):
+def createPyWrapper(pydir, wfile, isGuiScript = True):
     """
     Create an executable wrapper for a Python script.
 
     @param pydir the name of the directory where the Python script will eventually
         be installed
     @param wfile the basename of the wrapper
+    @param isGuiScript flag indicating a wrapper script for a GUI
+        application (boolean)
     @return the platform specific name of the wrapper
     """
     # all kinds of Windows systems
     if sys.platform.startswith("win"):
         wname = wfile + ".bat"
-        wrapper = \
-'''@"%s\\pythonw" "%s\\%s.py" %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9
-''' % (platBinDir, pydir, wfile)
+        if isGuiScript:
+            wrapper = \
+                '''@echo off\r\n''' \
+                '''set PYDIR=%%~dp0\r\n''' \
+                '''start "" "%%PYDIR%%\\pythonw.exe"''' \
+                ''' "%s\\%s.pyw"''' \
+                ''' %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\r\n''' % (pydir, wfile)
+        else:
+            wrapper = \
+                '''@"%s\\python.exe" "%s\\%s.py"''' \
+                ''' %%1 %%2 %%3 %%4 %%5 %%6 %%7 %%8 %%9\r\n''' % (
+                    platBinDir, pydir, wfile)
 
     # Mac OS X
     elif sys.platform == "darwin":
@@ -179,7 +206,7 @@ exec "%s" "%s/%s.py" "$@"
     return wname
 
 
-def copyTree(src, dst, filters, excludeDirs=[]):
+def copyTree(src, dst, filters, excludeDirs=[], excludePatterns=[]):
     """
     Copy Python, translation, documentation, wizards configuration,
     designer template files and DTDs of a directory tree.
@@ -188,6 +215,7 @@ def copyTree(src, dst, filters, excludeDirs=[]):
     @param dst name of the destination directory
     @param filters list of filter pattern determining the files to be copied
     @param excludeDirs list of (sub)directories to exclude from copying
+    @keyparam excludePatterns list of filter pattern determining the files to be skipped
     """
     try:
         names = os.listdir(src)
@@ -195,17 +223,23 @@ def copyTree(src, dst, filters, excludeDirs=[]):
         return      # ignore missing directories (most probably the i18n directory)
     
     for name in names:
-        srcname = os.path.join(src, name)
-        dstname = os.path.join(dst, name)
-        for filter in filters:
-            if fnmatch.fnmatch(srcname, filter):
-                if not os.path.isdir(dst):
-                    os.makedirs(dst)
-                shutil.copy2(srcname, dstname)
+        skipIt = False
+        for excludePattern in excludePatterns:
+            if fnmatch.fnmatch(name, excludePattern):
+                skipIt = True
                 break
-        else:
-            if os.path.isdir(srcname) and not srcname in excludeDirs:
-                copyTree(srcname, dstname, filters)
+        if not skipIt:
+            srcname = os.path.join(src, name)
+            dstname = os.path.join(dst, name)
+            for filter in filters:
+                if fnmatch.fnmatch(srcname, filter):
+                    if not os.path.isdir(dst):
+                        os.makedirs(dst)
+                    shutil.copy2(srcname, dstname)
+                    break
+            else:
+                if os.path.isdir(srcname) and not srcname in excludeDirs:
+                    copyTree(srcname, dstname, filters, excludePatterns=excludePatterns)
 
 
 def createGlobalPluginsDir():
@@ -254,68 +288,94 @@ def cleanUp():
         "eric4-tray", "eric4-editor", 
         "eric4-plugininstall", "eric4-pluginuninstall", 
         "eric4-pluginrepository", "eric4-sqlbrowser", 
-        "eric4-webbrowser", 
+        "eric4-webbrowser", "eric4-iconeditor", 
+        "eric4_api", "eric4_compare",
+        "eric4_configure", "eric4_diff",
+        "eric4_doc", "eric4_helpviewer",
+        "eric4_qregexp", "eric4_re", 
+        "eric4_trpreviewer", "eric4_uipreviewer",
+        "eric4_unittest", "eric4",
+        "eric4_tray", "eric4_editor", 
+        "eric4_plugininstall", "eric4_pluginuninstall", 
+        "eric4_pluginrepository", "eric4_sqlbrowser", 
+        "eric4_webbrowser", "eric4_iconeditor", 
     ]
-    for rem_wname in rem_wnames:
-        rwname = wrapperName(getConfig('bindir'), rem_wname)
-        if os.path.exists(rwname):
-            os.remove(rwname)
     
-    # Cleanup our config file(s)
-    for name in ['eric4config.py', 'eric4config.pyc', 'eric4.pth']:
-        e4cfile = os.path.join(pyModDir, name)
-        if os.path.exists(e4cfile):
-            os.remove(e4cfile)
-        
-    # Cleanup the install directories
-    for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir', 'ericCSSDir',
-                 'ericIconDir', 'ericPixDir', 'ericDir', 'ericTemplatesDir',
-                 'ericCodeTemplatesDir', 'ericOthersDir', 'ericStylesDir']:
-        if os.path.exists(getConfig(name)):
-            shutil.rmtree(getConfig(name), True)
-    
-    # Cleanup translations
-    for name in glob.glob(os.path.join(getConfig('ericTranslationsDir'), 'eric4_*.qm')):
-        if os.path.exists(name):
-            os.remove(name)
-    
-    # Cleanup API files
     try:
-        apidir = getConfig('apidir')
-        for progLanguage in progLanguages:
-            for name in getConfig('apis'):
-                apiname = os.path.join(apidir, progLanguage, name)
-                if os.path.exists(apiname):
-                    os.remove(apiname)
-    except AttributeError:
-        pass
+        for rem_wname in rem_wnames:
+            rwname = wrapperName(getConfig('bindir'), rem_wname)
+            if os.path.exists(rwname):
+                os.remove(rwname)
+        
+        # Cleanup our config file(s)
+        for name in ['eric4config.py', 'eric4config.pyc', 'eric4.pth']:
+            e4cfile = os.path.join(pyModDir, name)
+            if os.path.exists(e4cfile):
+                os.remove(e4cfile)
+            
+        # Cleanup the install directories
+        for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir', 'ericCSSDir',
+                     'ericIconDir', 'ericPixDir', 'ericDir', 'ericTemplatesDir',
+                     'ericCodeTemplatesDir', 'ericOthersDir', 'ericStylesDir']:
+            if os.path.exists(getConfig(name)):
+                shutil.rmtree(getConfig(name), True)
+        
+        # Cleanup translations
+        for name in glob.glob(os.path.join(getConfig('ericTranslationsDir'), 'eric4_*.qm')):
+            if os.path.exists(name):
+                os.remove(name)
+        
+        # Cleanup API files
+        try:
+            apidir = getConfig('apidir')
+            for progLanguage in progLanguages:
+                for name in getConfig('apis'):
+                    apiname = os.path.join(apidir, progLanguage, name)
+                    if os.path.exists(apiname):
+                        os.remove(apiname)
+        except AttributeError:
+            pass
+        
+        if sys.platform == "darwin":
+            # delete the Mac app bundle
+            if os.path.exists("/Developer/Applications/Eric4"):
+                shutil.rmtree("/Developer/Applications/Eric4")
+        
+    except IOError, msg:
+        sys.stderr.write('IOError: %s\nTry install with admin rights.\n' % msg)
+        exit(7)
+        
+    except OSError, msg:
+        sys.stderr.write('OSError: %s\nTry install with admin rights.\n' % msg)
+        exit(7)
 
 
 def installEric():
     """
     Actually perform the installation steps.
     """
-    global distDir, doCleanup, cfg, progLanguages
+    global distDir, doCleanup, cfg, progLanguages, sourceDir, configName
     
     # Create the platform specific wrappers.
     wnames = []
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-api"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-compare"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-configure"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-diff"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-doc"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-webbrowser"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-qregexp"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-re"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-trpreviewer"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-uipreviewer"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-unittest"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-tray"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-editor"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-plugininstall"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-pluginuninstall"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-pluginrepository"))
-    wnames.append(createPyWrapper(cfg['ericDir'], "eric4-sqlbrowser"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_api", False))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_compare"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_configure"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_diff"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_doc", False))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_editor"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_iconeditor"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_plugininstall"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_pluginrepository"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_pluginuninstall"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_qregexp"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_re"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_sqlbrowser"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_tray"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_trpreviewer"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_uipreviewer"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_unittest"))
+    wnames.append(createPyWrapper(cfg['ericDir'], "eric4_webbrowser"))
     wnames.append(createPyWrapper(cfg['ericDir'], "eric4"))
     
     # set install prefix, if not None
@@ -332,86 +392,175 @@ def installEric():
         
         # copy the eric4 config file
         if distDir:
-            shutil.copy('eric4config.py', cfg['mdir'])
-            if os.path.exists('eric4config.pyc'):
-                shutil.copy('eric4config.pyc', cfg['mdir'])
+            shutil.copy(configName, cfg['mdir'])
+            if os.path.exists(configName + 'c'):
+                shutil.copy(configName + 'c', cfg['mdir'])
         else:
-            shutil.copy('eric4config.py', modDir)
-            if os.path.exists('eric4config.pyc'):
-                shutil.copy('eric4config.pyc', modDir)
+            shutil.copy(configName, modDir)
+            if os.path.exists(configName + 'c'):
+                shutil.copy(configName + 'c', modDir)
         
         # copy the eric4.pth file
         if distDir:
-            shutil.copy('eric%seric4.pth' % os.sep, cfg['mdir'])
+            shutil.copy('%s%seric4.pth' % (sourceDir, os.sep), cfg['mdir'])
         else:
-            shutil.copy('eric%seric4.pth' % os.sep, modDir)
+            shutil.copy('%s%seric4.pth' % (sourceDir, os.sep), modDir)
         
         # copy the various parts of eric4
-        copyTree('eric', cfg['ericDir'], ['*.py', '*.pyc', '*.pyo', '*.pyw'], 
-            ['eric%sExamples' % os.sep])
-        copyTree('eric', cfg['ericDir'], ['*.rb'], 
-            ['eric%sExamples' % os.sep])
-        copyTree('eric%sPlugins' % os.sep, '%s%sPlugins' % (cfg['ericDir'], os.sep), 
+        copyTree(sourceDir, cfg['ericDir'], ['*.py', '*.pyc', '*.pyo', '*.pyw'], 
+            ['%s%sExamples' % (sourceDir, os.sep)],
+            excludePatterns=["eric4config.py*"])
+        copyTree(sourceDir, cfg['ericDir'], ['*.rb'], 
+            ['%s%sExamples' % (sourceDir, os.sep)])
+        copyTree('%s%sPlugins' % (sourceDir, os.sep), 
+            '%s%sPlugins' % (cfg['ericDir'], os.sep), 
             ['*.png'])
-        copyTree('eric%sDocumentation' % os.sep, cfg['ericDocDir'], ['*.html', '*.qch'])
-        copyTree('eric%sDTDs' % os.sep, cfg['ericDTDDir'], ['*.dtd'])
-        copyTree('eric%sCSSs' % os.sep, cfg['ericCSSDir'], ['*.css'])
-        copyTree('eric%sStyles' % os.sep, cfg['ericStylesDir'], ['*.qss'])
-        copyTree('eric%si18n' % os.sep, cfg['ericTranslationsDir'], ['*.qm'])
-        copyTree('eric%sicons' % os.sep, cfg['ericIconDir'], ['*.png', 'LICENSE*.*'])
-        copyTree('eric%spixmaps' % os.sep, cfg['ericPixDir'], ['*.png', '*.xpm', '*.ico'])
-        copyTree('eric%sDesignerTemplates' % os.sep, cfg['ericTemplatesDir'], ['*.tmpl'])
-        copyTree('eric%sCodeTemplates' % os.sep, cfg['ericCodeTemplatesDir'], ['*.tmpl'])
-        copyTree('eric%sExamples' % os.sep, cfg['ericExamplesDir'], 
+        copyTree('%s%sDocumentation' % (sourceDir, os.sep), 
+                 cfg['ericDocDir'], ['*.html', '*.qch'])
+        copyTree('%s%sDTDs' % (sourceDir, os.sep), 
+                 cfg['ericDTDDir'], ['*.dtd'])
+        copyTree('%s%sCSSs' % (sourceDir, os.sep), 
+                 cfg['ericCSSDir'], ['*.css'])
+        copyTree('%s%sStyles' % (sourceDir, os.sep), 
+                 cfg['ericStylesDir'], ['*.qss'])
+        copyTree('%s%si18n' % (sourceDir, os.sep), 
+                 cfg['ericTranslationsDir'], ['*.qm'])
+        copyTree('%s%sicons' % (sourceDir, os.sep), 
+                 cfg['ericIconDir'], ['*.png', 'LICENSE*.*'])
+        copyTree('%s%spixmaps' % (sourceDir, os.sep), 
+                 cfg['ericPixDir'], ['*.png', '*.xpm', '*.ico'])
+        copyTree('%s%sDesignerTemplates' % (sourceDir, os.sep), 
+                 cfg['ericTemplatesDir'], ['*.tmpl'])
+        copyTree('%s%sCodeTemplates' % (sourceDir, os.sep), 
+                 cfg['ericCodeTemplatesDir'], ['*.tmpl'])
+        copyTree('%s%sExamples' % (sourceDir, os.sep), cfg['ericExamplesDir'], 
                  ['*.py', '*.pyc', '*.pyo'])
         
         # copy the wrappers
         for wname in wnames:
             shutil.copy(wname, cfg['bindir'])
+            os.remove(wname)
         
         # copy the license file
-        shutil.copy('eric%sLICENSE.GPL3' % os.sep, cfg['ericDir'])
+        shutil.copy('%s%sLICENSE.GPL3' % (sourceDir, os.sep), cfg['ericDir'])
         
         # create the global plugins directory
         createGlobalPluginsDir()
         
     except IOError, msg:
-        sys.stderr.write('IOError: %s\nTry install as root.\n' % msg)
-        sys.exit(7)
+        sys.stderr.write('IOError: %s\nTry install with admin rights.\n' % msg)
+        exit(7)
         
     except OSError, msg:
         sys.stderr.write('OSError: %s\nTry install with admin rights.\n' % msg)
-        sys.exit(7)
+        exit(7)
     
     # copy some text files to the doc area
     for name in ["LICENSE.GPL3", "THANKS", "changelog"]:
         try:
-            shutil.copy('eric%s%s' % (os.sep, name), cfg['ericDocDir'])
+            shutil.copy('%s%s%s' % (sourceDir, os.sep, name), cfg['ericDocDir'])
         except EnvironmentError:
-            print "Could not install 'eric%s%s'." % (os.sep, name)
-    for name in glob.glob(os.path.join('eric', 'README*.*')):
+            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
+    for name in glob.glob(os.path.join(sourceDir, 'README*.*')):
         try:
             shutil.copy(name, cfg['ericDocDir'])
         except EnvironmentError:
-            print "Could not install 'eric%s%s'." % (os.sep, name)
+            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
    
     # copy some more stuff
-    for name in ['default.e4k']:
+    for name in ['default.e4k', 'default_Mac.e4k']:
         try:
-            shutil.copy('eric%s%s' % (os.sep, name), cfg['ericOthersDir'])
+            shutil.copy('%s%s%s' % (sourceDir, os.sep, name), cfg['ericOthersDir'])
         except EnvironmentError:
-            print "Could not install 'eric%s%s'." % (os.sep, name)
+            print "Could not install '%s%s%s'." % (sourceDir, os.sep, name)
     
     # install the API file
     for progLanguage in progLanguages:
         apidir = os.path.join(cfg['apidir'], progLanguage.lower())
         if not os.path.exists(apidir):
             os.makedirs(apidir)
-        for apiName in glob.glob(os.path.join("eric", "APIs", progLanguage, "*.api")):
+        for apiName in glob.glob(os.path.join(sourceDir, "APIs", progLanguage, "*.api")):
             try:
                 shutil.copy(apiName, apidir)
             except EnvironmentError:
                 print "Could not install '%s'." % apiName
+    
+    # Create a Mac application bundle
+    if sys.platform == "darwin":
+        createMacAppBundle(cfg['ericDir'])
+
+
+def createMacAppBundle(pydir):
+    """
+    Create a Mac application bundle.
+
+    @param pydir the name of the directory where the Python script will eventually
+        be installed
+    """
+    global cfg, sourceDir
+    
+    dirs = {"contents": "/Developer/Applications/Eric4/eric4.app/Contents/",
+            "exe": "/Developer/Applications/Eric4/eric4.app/Contents/MacOS",
+            "icns": "/Developer/Applications/Eric4/eric4.app/Contents/Resources"}
+    os.makedirs(dirs["contents"])
+    os.mkdir(dirs["exe"])
+    os.mkdir(dirs["icns"])
+    
+    starter = os.path.join(dirs["exe"], "eric")
+    os.symlink(
+        "%s/Resources/Python.app/Contents/MacOS/Python" % sys.exec_prefix,
+        starter)
+    
+    wname = os.path.join(dirs["exe"], "eric4")
+    path = os.getenv("PATH", "")
+    if path:
+        pybin = os.path.join(sys.exec_prefix, "bin")
+        pathlist = path.split(os.pathsep)
+        if pybin not in pathlist:
+            pathlist.insert(0, pybin)
+        path = os.pathsep.join(pathlist)
+        wrapper = \
+'''#!/bin/sh
+
+PATH=%s
+exec "%s" "%s/%s.py" "$@"
+''' % (path, starter, pydir, "eric4")
+    else:
+        wrapper = \
+'''#!/bin/sh
+
+exec "%s" "%s/%s.py" "$@"
+''' % (starter, pydir, "eric4")
+    copyToFile(wname, wrapper)
+    os.chmod(wname, 0755)
+    
+    shutil.copy(os.path.join(sourceDir, "pixmaps", "eric_2.icns"),
+                os.path.join(dirs["icns"], "eric.icns"))
+    
+    copyToFile(os.path.join(dirs["contents"], "Info.plist"),
+'''<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN"
+          "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+    <key>CFBundleExecutable</key>
+    <string>eric4</string>
+    <key>CFBundleIconFile</key>
+    <string>eric.icns</string>
+    <key>CFBundleInfoDictionaryVersion</key>
+    <string>1.0</string>
+    <key>CFBundleName</key>
+    <string>eric4</string>
+    <key>CFBundlePackageType</key>
+    <string>APPL</string>
+    <key>CFBundleSignature</key>
+    <string>????</string>
+    <key>CFBundleVersion</key>
+    <string>1.0</string>
+</dict>
+</plist>
+'''        
+    )
 
 
 def createInstallConfig():
@@ -442,16 +591,17 @@ def createInstallConfig():
     else:
         cfg['apidir'] = os.path.join(ericdir, "api")
 configLength = 15
-    
+
+
 def createConfig():
     """
     Create a config file with the respective config entries.
     """
-    global cfg
+    global cfg, sourceDir
     
     apis = []
     for progLanguage in progLanguages:
-        for apiName in glob.glob(os.path.join("eric", "APIs", progLanguage, "*.api")):
+        for apiName in glob.glob(os.path.join(sourceDir, "APIs", progLanguage, "*.api")):
             apis.append(os.path.basename(apiName))
     
     fn = 'eric4config.py'
@@ -502,6 +652,7 @@ def getConfig(name):
        cfg['apidir'], apis)
     copyToFile(fn, config)
 
+
 def doDependancyChecks():    
     """
     Perform some dependency checks.
@@ -509,20 +660,27 @@ def doDependancyChecks():
     print 'Checking dependencies'
     
     # perform dependency checks
-    if sys.version_info < (2, 5, 0):
-        print 'Sorry, you must have Python 2.5.0 or higher.'
-        sys.exit(5)
+    if sys.version_info < (2, 6, 0):
+        print 'Sorry, you must have Python 2.6.0 or higher.'
+        exit(5)
     if sys.version_info > (2, 9, 9):
         print 'Sorry, eric4 requires Python 2 for running.'
-        sys.exit(5)
+        exit(5)
     print "Python Version: %d.%d.%d" % sys.version_info[:3]
     
+    try:
+        import xml.etree
+    except ImportError, msg:
+        print('Your Python installation is missing the XML module.')
+        print('Please install it and try again.')
+        exit(5)
+    
     try:
         from PyQt4.QtCore import qVersion, PYQT_VERSION
     except ImportError, msg:
         print 'Sorry, please install PyQt4.'
         print 'Error: %s' % msg
-        sys.exit(1)
+        exit(1)
     print "Found PyQt4"
     
     try:
@@ -530,7 +688,7 @@ def doDependancyChecks():
     except ImportError, msg:
         print 'Sorry, please install QtHelp.'
         print 'Error: %s' % msg
-        sys.exit(1)
+        exit(1)
     print "Found QtHelp"
     
     try:
@@ -539,15 +697,15 @@ def doDependancyChecks():
         print "Sorry, please install QScintilla2 and"
         print "it's PyQt4 wrapper."
         print 'Error: %s' % msg
-        sys.exit(1)
+        exit(1)
     print "Found QScintilla2"
     
     # check version of Qt
     qtMajor = int(qVersion().split('.')[0])
     qtMinor = int(qVersion().split('.')[1])
-    if qtMajor < 4 or (qtMajor == 4 and qtMinor < 4):
-        print 'Sorry, you must have Qt version 4.4.0 or higher.'
-        sys.exit(2)
+    if qtMajor < 4 or (qtMajor == 4 and qtMinor < 6):
+        print 'Sorry, you must have Qt version 4.6.0 or higher.'
+        exit(2)
     print "Qt Version: %s" % qVersion()
     
     # check version of sip
@@ -561,7 +719,7 @@ def doDependancyChecks():
                 if vers == sipVersion:
                     print 'Sorry, sip version %s is not compatible with eric4.' % vers
                     print 'Please install another version.'
-                    sys.exit(3)
+                    exit(3)
     except ImportError:
         pass
     
@@ -576,16 +734,16 @@ def doDependancyChecks():
         maj = int(maj)
         min = int(min)
         pat = int(pat)
-        if maj < 4 or (maj == 4 and min < 3):
-            print 'Sorry, you must have PyQt 4.3.0 or higher or' \
+        if maj < 4 or (maj == 4 and min < 6):
+            print 'Sorry, you must have PyQt 4.6.0 or higher or' \
                   ' a recent snapshot release.'
-            sys.exit(4)
+            exit(4)
         # check for blacklisted versions
         for vers in BlackLists["PyQt4"]:
             if vers == pyqtVersion:
                 print 'Sorry, PyQt4 version %s is not compatible with eric4.' % vers
                 print 'Please install another version.'
-                sys.exit(4)
+                exit(4)
     print "PyQt Version: ", pyqtVersion
     
     #check version of QScintilla
@@ -599,24 +757,26 @@ def doDependancyChecks():
         maj = int(maj)
         min = int(min)
         pat = int(pat)
-        if maj < 2 or (maj == 2 and min < 2):
-            print 'Sorry, you must have QScintilla 2.2.0 or higher or' \
+        if maj < 2 or (maj == 2 and min < 3):
+            print 'Sorry, you must have QScintilla 2.3.0 or higher or' \
                   ' a recent snapshot release.'
-            sys.exit(5)
+            exit(5)
         # check for blacklisted versions
         for vers in BlackLists["QScintilla2"]:
             if vers == scintillaVersion:
                 print 'Sorry, QScintilla2 version %s is not compatible with eric4.' % vers
                 print 'Please install another version.'
-                sys.exit(5)
+                exit(5)
     print "QScintilla Version: ", QSCINTILLA_VERSION_STR
     print "All dependencies ok."
     print
 
+
 def compileUiFiles():
     """
     Compile the .ui files to Python sources.
     """
+    global sourceDir
     try:
         from PyQt4.uic import compileUiDir
     except ImportError:
@@ -695,7 +855,8 @@ def compileUiFiles():
         """
         return py_dir, "Ui_%s" % py_file
     
-    compileUiDir("eric", True, pyName)
+    compileUiDir(sourceDir, True, pyName)
+
 
 def main(argv):
     """
@@ -707,7 +868,12 @@ def main(argv):
 
     # Parse the command line.
     global progName, modDir, doCleanup, doCompile, distDir, cfg, apisDir
+    global sourceDir, configName
+    
     progName = os.path.basename(argv[0])
+    
+    if os.path.dirname(argv[0]):
+      os.chdir(os.path.dirname(argv[0]))
 
     initGlobals()
 
@@ -746,10 +912,15 @@ def main(argv):
                 if len(cfg) != configLength:
                     print "The configuration dictionary in '%s' is incorrect. Aborting"\
                         % arg
-                    sys.exit(6)
+                    exit(6)
             except:
                 cfg = {}
     
+    installFromSource = not os.path.isdir(sourceDir)
+    if installFromSource:
+        sourceDir = os.path.dirname(__file__) or "."
+        configName = os.path.join(sourceDir, "eric4config.py")
+    
     if len(cfg) == 0:
         createInstallConfig()
     
@@ -758,7 +929,12 @@ def main(argv):
     
     # get rid of development config file, if it exists
     try:
-        os.remove(os.path.join("eric", "eric4config.py"))
+        if installFromSource:
+            os.rename(configName, configName + ".orig")
+            configNameC = configName + 'c'
+            if os.path.exists(configNameC):
+                os.remove(configNameC)
+        os.remove(configName)
     except EnvironmentError:
         pass
     
@@ -782,21 +958,33 @@ def main(argv):
     if doCompile:
         print "\nCompiling source files..."
         if distDir:
-            compileall.compile_dir("eric", 
+            compileall.compile_dir(sourceDir, 
                                    ddir = os.path.join(distDir, modDir, cfg['ericDir']), 
                                    rx = re.compile("Python3"), 
                                    quiet = True)
-            py_compile.compile("eric4config.py", 
+            py_compile.compile(configName, 
                                dfile = os.path.join(distDir, modDir, "eric4config.py"))
         else:
-            compileall.compile_dir("eric", 
+            compileall.compile_dir(sourceDir, 
                                    ddir = os.path.join(modDir, cfg['ericDir']), 
                                    rx = re.compile("Python3"), 
                                    quiet = True)
-            py_compile.compile("eric4config.py", 
+            py_compile.compile(configName, 
                                dfile = os.path.join(modDir, "eric4config.py"))
     print "\nInstalling eric4 ..."
     installEric()
+    
+    # do some cleanup
+    try:
+        if installFromSource:
+            os.remove(configName)
+            configNameC = configName + 'c'
+            if os.path.exists(configNameC):
+                os.remove(configNameC)
+            os.rename(configName + ".orig", configName)
+    except EnvironmentError:
+        pass
+    
     print "\nInstallation complete."
     print
     
