@@ -1,6 +1,7 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2009 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002-2012 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the uninstall script for eric4.
 
@@ -47,7 +48,7 @@ def initGlobals():
 def wrapperName(dname,wfile):
     """Create the platform specific name for the wrapper script.
     """
-    if sys.platform == "win32":
+    if sys.platform.startswith("win"):
         wname = dname + "\\" + wfile + ".bat"
     else:
         wname = dname + "/" + wfile
@@ -71,15 +72,26 @@ def uninstallEric():
         "eric4-unittest", "eric4",
         "eric4-tray", "eric4-editor", 
         "eric4-plugininstall", "eric4-pluginuninstall", 
-        "eric4-pluginrepository", 
+        "eric4-pluginrepository", "eric4-sqlbrowser", 
+        "eric4-webbrowser", "eric4-iconeditor", 
+        "eric4_api", "eric4_compare",
+        "eric4_configure", "eric4_diff",
+        "eric4_doc", "eric4_helpviewer",
+        "eric4_qregexp", "eric4_re", 
+        "eric4_trpreviewer", "eric4_uipreviewer",
+        "eric4_unittest", "eric4",
+        "eric4_tray", "eric4_editor", 
+        "eric4_plugininstall", "eric4_pluginuninstall", 
+        "eric4_pluginrepository", "eric4_sqlbrowser", 
+        "eric4_webbrowser", "eric4_iconeditor", 
     ]
     for rem_wname in rem_wnames:
         rwname = wrapperName(getConfig('bindir'),rem_wname)
         if os.path.exists(rwname):
             os.remove(rwname)
     
-    # Cleanup our config file
-    for name in ['eric4config.py', 'eric4config.pyc']:
+    # Cleanup our config file(s)
+    for name in ['eric4config.py', 'eric4config.pyc', 'eric4.pth']:
         e4cfile = os.path.join(pyModDir, name)
         if os.path.exists(e4cfile):
             os.remove(e4cfile)
@@ -104,6 +116,11 @@ def uninstallEric():
         if os.path.exists(apiname):
             os.remove(apiname)
     
+    if sys.platform == "darwin":
+        # delete the Mac app bundle
+        if os.path.exists("/Developer/Applications/Eric4"):
+            shutil.rmtree("/Developer/Applications/Eric4")
+    
 def main(argv):
     """The main function of the script.
 
@@ -131,7 +148,9 @@ def main(argv):
     try:
         uninstallEric()
     except IOError, msg:
-        sys.stderr.write('IOError: %s\nTry uninstall as root.\n' % msg)
+        sys.stderr.write('IOError: %s\nTry uninstall with admin rights.\n' % msg)
+    except OSError, msg:
+        sys.stderr.write('OSError: %s\nTry uninstall with admin rights.\n' % msg)
     
     
 if __name__ == "__main__":
@@ -142,6 +161,6 @@ if __name__ == "__main__":
     except:
         print \
 """An internal error occured.  Please report all the output of the program,
-including the following traceback, to eric4-bugs@die-offenbachs.de.
+including the following traceback, to eric4-bugs@eric-ide.python-projects.org.
 """
         raise
